//#include <edc_examp.h>
#include <csl_edc.h>
#include <csl_idma.h>
#include <csl_cache.h>
#include <stdio.h>

/* Number of elements for data read and write */
#define NUM_ELEMENTS 512

/* Compile-time constants these are set equal to the L2 and L1P size */
#pragma DATA_SECTION (edc_umc_test_buf_rx, "EDC_BUF0")
#pragma DATA_SECTION (edc_umc_buf_tx, "EDC_BUF1")
#pragma DATA_SECTION (edc_pmc_tx, "EDC_BUF2")

/* EDC ERROR CHECK Structure This is modified when introducing EDC error 
 * and compare in the NMI ISR for errors
 */
typedef struct edcErrorConfig {  
    Uint32 Actual_Addr;
    Uint32 ADDR;
    Uint32 SRAM;
       
} edcErrorCheckStruct;
edcErrorCheckStruct EDC_INTRODUCED;

/* Global variable declarations */
volatile Uint32     umc_ed_pass = 0;                                                
volatile Uint32     test = 0xABCDABCD; 
Uint32              edc_umc_test_buf_rx[NUM_ELEMENTS];
Uint32              edc_umc_buf_tx[NUM_ELEMENTS];
Uint32              edc_pmc_tx[NUM_ELEMENTS];
CSL_Status          status;

void edc_err_gen_code (void) 
{   
    
    /* Disable L1P Cache */
    CACHE_setL1pSize(CACHE_L1_0KCACHE);
    
    /* Disable L1D Cache */
    CACHE_setL1dSize(CACHE_L1_0KCACHE);
    
    /* Initialize the IDMA */
    IDMA1_init(IDMA_PRI_7, IDMA_INT_EN);
    
    /* Write L2 -> L1P */
    IDMA1_copy(edc_umc_test_buf_rx, edc_pmc_tx, 0x100);

    /* IDMA WR L1P->L2 */
    IDMA1_copy(edc_pmc_tx,  edc_umc_test_buf_rx , 0x100);

    /* Wait until copying is completed */
    IDMA1_wait();
    
    /* EDC ERROR Structure modification */
    EDC_INTRODUCED.Actual_Addr = ( Uint32) &edc_umc_test_buf_rx;
       
    /* Suspend the Parity generation */
   CSL_edcSuspend(CSL_EDC_L2);
   
    
    /* Inject an error */
    edc_umc_buf_tx[0] = 0x20;    
    IDMA1_copy(edc_umc_buf_tx, edc_umc_test_buf_rx, 0x100);

    /* Wait until copying is completed */
    IDMA1_wait();

    /* Re-enable EDC */  
    CSL_edcEnable(CSL_EDC_L2);
   
    /* IDMA- PMC Read  */
    IDMA1_copy(edc_umc_test_buf_rx, edc_pmc_tx, 0x30);

    /* Wait until copying is completed */
    IDMA1_wait();
     
}
