/* ===============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 * ===============================================================================
 */
/** ==============================================================================
 *   @file  csl_adtf2GetHwStatus.c
 *
 *   @path  $(CSLPATH)\adtf2\src
 *
 *   @desc
 *
 */
/* ===============================================================================
 *  Revision History
 *  ===============
 *  30-Apr-2008 File Created
 *
 * ===============================================================================
 */
#include <csl_adtf2.h>


#pragma CODE_SECTION (CSL_adtf2GetHwStatus, ".text:csl_section:adtf2");

CSL_Status  CSL_adtf2GetHwStatus (
    CSL_Adtf2Handle           hAdtf2,
    CSL_Adtf2HwStatusQuery    query,
    void                    *response
)
{
    CSL_Status status = CSL_SOK;

    if (hAdtf2 == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }

    else {
        switch (query) {
            case CSL_ADTF2_QUERY_INPUTWIDTH:
                /* Queries the ADTF2 input width */
                *(Uint32 *)response = (CSL_FEXT(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_INPUTWIDTH));
                break;

            case CSL_ADTF2_QUERY_ATID:
                /* Queries ADTF2 Trace ID Register */
                *(Uint32 *)response =
                    (CSL_FEXT( hAdtf2->regs->ADTFTID, ADTF2_ADTFTID_ATID));
                break;

            case CSL_ADTF2_QUERY_ADTF2ENABLE:
                /* Queries ADTF2 is ENABLED or DISABLED */
                *(Uint32 *)response =
                    (CSL_FEXT( hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_ADTFEN));
                break;

            case CSL_ADTF2_QUERY_NOPDISCARD:
                /* Queries whether NOP need to be discarded or not */
                *(Uint32 *)response =
                    (CSL_FEXT( hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_NOP_DISCARD));
                break;

			case CSL_ADFT2_OVERFLOW:
				/* Queries Overflow status */
				*(Uint32 *)response =
					(CSL_FEXT( hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_OVERFLOW));
                break;

			case CSL_ADFT2_TRIGGERSTATUS:
				/* Queries trigger status */
				*(Uint32 *)response =
					(CSL_FEXT( hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_TRIGGEREN));
                break;

			case CSL_ADFT2_MULTIPACKET_STATUS:
				/* Queries multipacket status */
				*(Uint32 *)response =
					(CSL_FEXT( hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_MULTIPACKET));
                break;

            default:
                status = CSL_ESYS_INVQUERY;
                break;
        }
    }
    return(status);
}

