/* ===============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 * ===============================================================================
 */
/** ==============================================================================
 *   @file  csl_adtf2HwControl.c
 *
 *   @path  $(CSLPATH)\src\adtf2
 *
 *   @desc
 *    - The CSL_adtf2HwControl() function definition & it's associated functions
 *
 */
/* ===============================================================================
 *  Revision History
 *  ===============
 *  30-Apr-2008 File Created
 *
 * ===============================================================================
 */
#include <csl_adtf2.h>


#pragma CODE_SECTION (CSL_adtf2HwControl, ".text:csl_section:adtf2");

CSL_Status  CSL_adtf2HwControl (
    CSL_Adtf2Handle        hAdtf2,
    CSL_Adtf2ControlCmd    cmd,
    void*                arg
)
{
    CSL_Status          status  = CSL_SOK;
    Uint32              argv = *(Uint32*)arg;

    if (hAdtf2 == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }

    else {
        switch (cmd) {

            case CSL_ADTF2_CMD_FLUSH_ADTF2FLUSH:
                /* Initiate Trace Flush */
                CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_FLUSHTRACE, FLUSH_TRACE);
                break;

            case CSL_ADTF2_CMD_ENA_ADTF2:
                /* ADTF2 is functional. */
                CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_ADTFEN, ADFT2_FUNCTIONAL);
                break;

			case CSL_ADTF2_CMD_DIS_ADTF2:
				/* Both DSP trace input and ATB output interfaces are disabled. */
				CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_ADTFEN, DISABLED);
                break;

            case CSL_ADTF2_CMD_RESETTRACE:
                /* Resetting the DSP Trace input interface to the ADTF */
                CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_RESETTRACE, RESET);
                break;

            case CSL_ADTF2_CMD_CLEAR_OVERFLOW:
                /* Clearing the overflow bit */
                CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_OVERFLOW, CLEAR);
                break;

            case CSL_ADTF2_CMD_ENA_TRIGGER:
                /* ADTF2 will generate a trigger out on the export interface each time a native trace trigger packet is seen on the input stream */
                CSL_FINST(hAdtf2->regs->ADTFCSR,ADTF2_ADTFCSR_TRIGGEREN, TRIGGER);
                break;

			case CSL_ADTF2_CMD_DIS_TRIGGER:
				/* No triggers are generated. */
				CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_TRIGGEREN, NO_TRIGGER);
                break;

            case CSL_ADTF2_CMD_ENA_MULTIPACKET:
                /* Each ATB export packets will contain three valid trace packets unless flush forces export with fewer.   */
                CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_MULTIPACKET, 3_TRACE_PACKETS);
                break;

			case CSL_ADTF2_CMD_ENA_SINGLEPACKET:
				/* Each ATB export packet will contain a single 10 bit trace packet (Single Packet mode). */
				CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_MULTIPACKET, 1_TRACE_PACKET);
                break;

			case CSL_ADTF2_CMD_ENA_NOP_DISCARD:
				/* ADTF2 removes trace NOP packets (00 0000 0000b) from the input stream before packing into ATB export packet.   */
				CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_NOP_DISCARD, REMOVE_NOPS);
			break;

			case CSL_ADTF2_CMD_DIS_NOP_DISCARD:
				/* All packets are placed in ATB export packet. */
				CSL_FINST(hAdtf2->regs->ADTFCSR, ADTF2_ADTFCSR_NOP_DISCARD, DONT_REMOVE_NOPS);
			break;

            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }
    return (status);
}

