/* ===============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 * ===============================================================================
 */
/** @file  csl_adtf2Open.c
 *
 *  @path $(CSLPATH)\src\adtf2\
 *
 *  @brief File for functional layer of CSL API @a CSL_adtf2Open()
 *
 */
/* ===============================================================================
 * Revision History
 * ===============
 *
 *  30-Apr-2008 File created
 * ===============================================================================
 */
#include <csl_adtf2.h>


#pragma CODE_SECTION (CSL_adtf2Open, ".text:csl_section:adtf2");

CSL_Adtf2Handle CSL_adtf2Open (
    CSL_Adtf2Obj 	*pAdtf2Obj,
    CSL_InstNum 	adtf2Num,
    CSL_Adtf2Param 	*pAdtf2Param,
    CSL_Status 		*pStatus
)
{
    CSL_Adtf2Handle           hAdtf2 = (CSL_Adtf2Handle) NULL;
    CSL_Adtf2BaseAddress      baseAddress;

    if (pStatus == NULL) {
        /* do nothing : already the module is initialized to NULL */
    }

    else if (pAdtf2Obj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }

    else {
        *pStatus = CSL_adtf2GetBaseAddress(adtf2Num, pAdtf2Param, &baseAddress);

            if (*pStatus == CSL_SOK) {
                pAdtf2Obj->regs = baseAddress.regs;
                pAdtf2Obj->adtf2Num = (CSL_InstNum)adtf2Num;
                hAdtf2 = (CSL_Adtf2Handle)pAdtf2Obj;
            }
            else {
                pAdtf2Obj->regs = (CSL_Adtf2RegsOvly) NULL;
                pAdtf2Obj->adtf2Num = (CSL_InstNum) -1;
            }

    }
    return (hAdtf2);
}

