/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 * Use of this software is controlled by the terms and conditions found
 * in the license agreement under which this software has been supplied
 * provided
 * ============================================================================
 */

/** ============================================================================
 *   @file  csl_bwmngmtGetHwSetup.c
 *
 *   @path  $(CSLPATH)\src\bwmngmt
 *
 *   @desc  File for functional layer of CSL API CSL_bwmngmtGetHwSetup()
 *
 */

/* =============================================================================
 * Revision History
 * ===============
 *  04-Jun-2004 Chad Courtney File Created
 *
 *  11-Apr-2005 Brn updated the file for doxygen compatibiliy
 *
 *  16-Nov-2005 ds  updated the documentation
 *  08-Sep-2008 Update for Doxygen
 * =============================================================================
 */

#include <csl_bwmngmt.h>

/* ============================================================================
 *   CSL_bwmngmtGetHwSetup
 *  ===========================================================================
 */
#pragma CODE_SECTION (CSL_bwmngmtGetHwSetup, ".text:csl_section:bwmngmt");
CSL_Status CSL_bwmngmtGetHwSetup (
    CSL_BwmngmtHandle    hBwmngmt,
    CSL_BwmngmtHwSetup   *hwSetup
)
{   
    CSL_Status status = CSL_SOK;
    Uint32 ControlBlock;
    
    if (hBwmngmt == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    
    else if (hwSetup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }

    else {
        ControlBlock =  hwSetup->control;

        if (ControlBlock == CSL_BWMNGMT_BLOCK_L1D) {

            hwSetup->cpuPriority = (CSL_BwmngmtPriority)
                       CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBD, 
                                                            BWMNGMT_CPUARBD_PRI);

            hwSetup->cpuMaxwait = (CSL_BwmngmtMaxwait)
                       CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBD, 
                                                        BWMNGMT_CPUARBD_MAXWAIT);

            hwSetup->idmaMaxwait = (CSL_BwmngmtMaxwait)  
                      CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->IDMAARBD, 
                                                       BWMNGMT_IDMAARBD_MAXWAIT);

            hwSetup->sdmaMaxwait = (CSL_BwmngmtMaxwait)  
                      CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->SDMAARBD, 
                                                       BWMNGMT_SDMAARBD_MAXWAIT);

            hwSetup->ucMaxwait = (CSL_BwmngmtMaxwait)  
                        CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->UCARBD, 
                                                         BWMNGMT_UCARBD_MAXWAIT);
        }
        else if (ControlBlock == CSL_BWMNGMT_BLOCK_L2) {

            hwSetup->cpuPriority = (CSL_BwmngmtPriority) 
                        CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBU, 
                                                             BWMNGMT_CPUARBU_PRI);    

            hwSetup->cpuMaxwait = (CSL_BwmngmtMaxwait)  
                        CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBU, 
                                                         BWMNGMT_CPUARBU_MAXWAIT);

            hwSetup->idmaMaxwait = (CSL_BwmngmtMaxwait)  
                       CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->IDMAARBU, 
                                                        BWMNGMT_IDMAARBU_MAXWAIT);

            hwSetup->sdmaMaxwait = (CSL_BwmngmtMaxwait)  
                       CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->SDMAARBU, 
                                                        BWMNGMT_SDMAARBU_MAXWAIT);

            hwSetup->ucMaxwait = (CSL_BwmngmtMaxwait)  
                         CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->UCARBU, 
                                                          BWMNGMT_UCARBU_MAXWAIT);             
        } 
        else if (ControlBlock == CSL_BWMNGMT_BLOCK_EXT) {

            hwSetup->cpuPriority = (CSL_BwmngmtPriority) 
                       CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBE, 
                                                            BWMNGMT_CPUARBE_PRI);  

            hwSetup->cpuMaxwait = (CSL_BwmngmtMaxwait)  
                       CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBE, 
                                                        BWMNGMT_CPUARBE_MAXWAIT);

            hwSetup->idmaMaxwait = (CSL_BwmngmtMaxwait)  
                      CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->IDMAARBE, 
                                                       BWMNGMT_IDMAARBE_MAXWAIT);

            hwSetup->sdmaMaxwait = (CSL_BwmngmtMaxwait)  
                      CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->SDMAARBE, 
                                                       BWMNGMT_SDMAARBE_MAXWAIT);

            hwSetup->mapPriority = (CSL_BwmngmtPriority) 
                       CSL_FEXT(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->MDMAARBE, 
                                                            BWMNGMT_MDMAARBE_PRI);             
        } 
        else { 
            status = CSL_ESYS_INVPARAMS;
        }

    }
    return status;
}


