/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 * Use of this software is controlled by the terms and conditions found
 * in the license agreement under which this software has been supplied
 * priovided
 * ============================================================================
 */

/** ============================================================================
 *   @file  csl_bwmngmtHwSetup.c
 *
 *   @path  $(CSLPATH)\src\bwmngmt
 *
 *   @desc  File for functional layer of CSL API CSL_bwmngmtHwSetup()
 *
 */

/* =============================================================================
 * Revision History
 * ===============
 *  03-Jun-2004 Chad Courtney File Created
 *
 *  11-Apr-2005 Brn updated the file for doxygen compatibiliy
 *
 *  16-Nov-2005 ds  updated the documentation
 *  08-Sep-2008 Update for Doxygen
 * =============================================================================
 */
 
#include <csl_bwmngmt.h>

/* ============================================================================
 *   CSL_bwmngmtHwSetup
 *  ===========================================================================
 */
#pragma CODE_SECTION (CSL_bwmngmtHwSetup, ".text:csl_section:bwmngmt");
CSL_Status CSL_bwmngmtHwSetup (
    CSL_BwmngmtHandle    hBwmngmt,
    CSL_BwmngmtHwSetup   *setup
)
{
    CSL_Status  status = CSL_SOK;
    Uint32      _tempControl;
    
    if (hBwmngmt == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    
    else if (setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }

    else {
        _tempControl =  setup->control;

        if (setup->cpuPriority != CSL_BWMNGMT_PRI_NULL) {

            if (_tempControl & CSL_BWMNGMT_BLOCK_L1D) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBD, 
                                        BWMNGMT_CPUARBD_PRI, setup->cpuPriority);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_L2) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBU, 
                                         BWMNGMT_CPUARBU_PRI, setup->cpuPriority);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_EXT) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBE, 
                                        BWMNGMT_CPUARBE_PRI, setup->cpuPriority);
            }
        }

        if (setup->cpuMaxwait != CSL_BWMNGMT_MAXWAIT_NULL) {

            if (_tempControl & CSL_BWMNGMT_BLOCK_L1D) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBD, 
                                     BWMNGMT_CPUARBD_MAXWAIT, setup->cpuMaxwait);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_L2) {

                CSL_FINS(((CSL_BwmngmtRegs*)CSL_BWMNGMT_0_REGS)->CPUARBU, 
                                      BWMNGMT_CPUARBU_MAXWAIT, setup->cpuMaxwait);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_EXT) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->CPUARBE, 
                                     BWMNGMT_CPUARBE_MAXWAIT, setup->cpuMaxwait);
            }
        }

        if (setup->idmaMaxwait != CSL_BWMNGMT_MAXWAIT_NULL) {

            if (_tempControl & CSL_BWMNGMT_BLOCK_L1D) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->IDMAARBD, 
                                   BWMNGMT_IDMAARBD_MAXWAIT, setup->idmaMaxwait);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_L2) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->IDMAARBU, 
                                     BWMNGMT_IDMAARBU_MAXWAIT, setup->idmaMaxwait);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_EXT) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->IDMAARBE, 
                                   BWMNGMT_IDMAARBE_MAXWAIT, setup->idmaMaxwait);
            }
        }

        if (setup->sdmaMaxwait != CSL_BWMNGMT_MAXWAIT_NULL) {

            if (_tempControl & CSL_BWMNGMT_BLOCK_L1D) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->SDMAARBD, 
                                   BWMNGMT_SDMAARBD_MAXWAIT, setup->sdmaMaxwait);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_L2) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->SDMAARBU, 
                                    BWMNGMT_SDMAARBU_MAXWAIT, setup->sdmaMaxwait);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_EXT) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->SDMAARBE, 
                                   BWMNGMT_SDMAARBE_MAXWAIT, setup->sdmaMaxwait);
            }
        }   

        if (setup->mapPriority != CSL_BWMNGMT_PRI_NULL) {

            if (_tempControl & CSL_BWMNGMT_BLOCK_EXT) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->MDMAARBE, 
                                        BWMNGMT_MDMAARBE_PRI, setup->mapPriority);
            }
        }

        if (setup->ucMaxwait != CSL_BWMNGMT_MAXWAIT_NULL) {

            if (_tempControl & CSL_BWMNGMT_BLOCK_L1D) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->UCARBD, 
                                       BWMNGMT_UCARBD_MAXWAIT, setup->ucMaxwait);
            }

            if (_tempControl & CSL_BWMNGMT_BLOCK_L2) {

                CSL_FINS(((CSL_BwmngmtRegs *)CSL_BWMNGMT_0_REGS)->UCARBU, 
                                        BWMNGMT_UCARBU_MAXWAIT, setup->ucMaxwait);
            }
        }   
                     
    }     
    return (status);
}


