/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 * Use of this software is controlled by the terms and conditions found
 * in the license agreement under which this software has been supplied
 * priovided
 * ============================================================================
 */

/** ============================================================================
 *   @file  csl_bwmngmtOpen.c
 *
 *   @path  $(CSLPATH)\src\bwmngmt
 *
 *   @desc  File for functional layer of CSL API CSL_bwmngmtOpen()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  03-Jun-2004 Chad Courtney File Created
 *  11-Apr-2005 Brn Updated the file for doxygen compatibiliy
 *  16-Nov-2005 ds  Updated the documentation
 *  31-Jan-2006 ds  Supported to use the CSL_bwmngmtGetBaseAddress() API
 *  08-Sep-2008 Update for Doxygen
 * =============================================================================
 */
 
#include <csl_bwmngmt.h>

/* ===========================================================================
 *    CSL_bwmngmtOpen
 * ===========================================================================
 */
#pragma CODE_SECTION (CSL_bwmngmtOpen, ".text:csl_section:bwmngmt");
CSL_BwmngmtHandle CSL_bwmngmtOpen (
    CSL_BwmngmtObj    *pBwmngmtObj,
    CSL_InstNum       bwmngmtNum,
    CSL_BwmngmtParam  *pBwmmngmtParam,
    CSL_Status        *pStatus
)
{
    CSL_BwmngmtHandle        hBwmngmt = (CSL_BwmngmtHandle)NULL;
    CSL_BwmngmtBaseAddress   baseAddress;
    
    if (pStatus == NULL) {
        /* do nothing : already the module is initialized to NULL */
    }
    
    else if (pBwmngmtObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }

    else {
        *pStatus = CSL_bwmngmtGetBaseAddress(bwmngmtNum, pBwmmngmtParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pBwmngmtObj->regs = baseAddress.regs;
            pBwmngmtObj->bwmngmtNum = (CSL_InstNum)bwmngmtNum;
            hBwmngmt = (CSL_BwmngmtHandle)pBwmngmtObj;
        }
        else {
            pBwmngmtObj->regs = (CSL_BwmngmtRegsOvly)NULL;
            pBwmngmtObj->bwmngmtNum = (CSL_InstNum)-1;
        }
    }
    return (hBwmngmt);   
}
