/*  ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_cacheEnable.c
 *
 *   @path  $(CSLPATH)\src\cache
 *
 *   @desc  File for functional layer of CSL API CACHE_enableCaching ()
 *
 */
 
/* =============================================================================
 *  Revision History
 *  ===============
 *  23-Mar-2004 Jamon Bowen File Created
 *  08-Sep-2008 Update for Doxygen
 *
 * ============================================================================= 
 */

#include <csl_cache.h>
#include <_csl_cache.h>

/* ============================================================================
 *    CACHE_enableCaching
 *  ============================================================================
 */

#pragma CODE_SECTION (CACHE_enableCaching, ".text:csl_section:cache");
void CACHE_enableCaching (
    CE_MAR          mar
)
{
    ((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->MAR[mar] = 1;
}

/** ============================================================================
 *   @n@b CACHE_disableCaching
 *
 *   @b Description
 *   @n This function disables caching for a specific memory region. 
 *
 *   @b Arguments
     @verbatim
          mar      Memory region for which cache is to be disabled.
     @endverbatim
 *
 *   <b> Return Value </b>
 *   @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n Memory region is now *not* cacheable.
 *
 *   @b Modifies
 *   @n MAR
 *
 *   @b Example
 *   @verbatim

        CACHE_disableCaching (CACHE_EMIFA_CE20);

     @endverbatim
 * =============================================================================
 */
#pragma CODE_SECTION (CACHE_disableCaching, ".text:cslsys_section:cache");

void CACHE_disableCaching (CE_MAR mar)
{
    ((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->MAR[mar] = 0;
}

