/*  ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *   @file  csl_cacheWait.c
 *
 *   @path  $(CSLPATH)\src\cache
 *
 *   @desc  File for functional layer of Cache Waite State
 *
 */
 
/* =============================================================================
 *  Revision History
 *  ===============
 * - 23-Mar-2004 Jamon Bowen File Created
 *
 *  21-Jun-2004 Ruchika Kharwar modified.
 *  08-Sep-2008 Update for Doxygen
 *
 * ============================================================================= 
 */
 
#include <csl_cache.h>
#include <_csl_cache.h>

/* ============================================================================
 *    CACHE_wait
 *
 *  ============================================================================
 */
#pragma CODE_SECTION (CACHE_wait, ".text:csl_section:cache");
void CACHE_wait (void)
{

    CACHE_waitInternal();
    _CSL_cacheApplyPatch();
    
    return;
}

/* ============================================================================
 *    CACHE_waitInternal
 *  ============================================================================
 */
#pragma CODE_SECTION (CACHE_waitInternal, ".text:csl_section:cache");
void CACHE_waitInternal(void)
{
    switch(_CSL_cachebusyState) {
        case CACHE_WAIT_NONE:
            break;
        
        case CACHE_WAIT_L1DINVALL:
            while (CSL_FEXT(((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L1DINV, \
                            CACHE_L1DINV_I) == \
                            CSL_CACHE_L1DINV_I_INV);
            break;
        
        case CACHE_WAIT_L1DINV:
            while (((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L1DIWC != 0);
            break;
        
        case CACHE_WAIT_L1DWBALL:
            while (CSL_FEXT(((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L1DWB, \
                            CACHE_L1DWB_C) == \
                            CSL_CACHE_L1DWB_C_WB);
            break;
        
        case CACHE_WAIT_L1DWB:
            while (((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L1DWWC != 0);
            break;
        
        case CACHE_WAIT_L1DWBINVALL:
            while (CSL_FEXT(((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L1DWBINV, \
                            CACHE_L1DWBINV_C) == \
                            CSL_CACHE_L1DWBINV_C_WBINV);
            break;
        
        case CACHE_WAIT_L1DWBINV:
            while (((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L1DWIWC != 0);
            break;
        
        case CACHE_WAIT_L1PINVALL:
            while (CSL_FEXT(((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L1PINV, \
                            CACHE_L1PINV_I) == \
                            CSL_CACHE_L1PINV_I_INV);
            break;
    
        case CACHE_WAIT_L1PINV:
            while (((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L1PIWC != 0);
            break;
    
        case CACHE_WAIT_L2INVALL:
            while (CSL_FEXT(((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L2INV, \
                            CACHE_L2INV_I) == \
                            CSL_CACHE_L2INV_I_INV);
            break;
    
        case CACHE_WAIT_L2INV:
            while (((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L2IWC != 0);
            break;
    
        case CACHE_WAIT_L2WBALL:
            while (CSL_FEXT(((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L2WB, \
                            CACHE_L2WB_C) == \
                            CSL_CACHE_L2WB_C_WB);
            break;
    
        case CACHE_WAIT_L2WB:
            while (((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L2WWC != 0);
            break;
    
        case CACHE_WAIT_L2WBINVALL:
            while (CSL_FEXT(((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L2WBINV, \
                            CACHE_L2WBINV_C) == \
                            CSL_CACHE_L2WBINV_C_WBINV);
            break;
    
        case CACHE_WAIT_L2WBINV:
            while (((CSL_CacheRegsOvly)CSL_CACHE_0_REGS)->L2WIWC != 0);
            break;
    
        default:
            break;
    }
    
    _CSL_cachebusyState = CACHE_WAIT_NONE;
}
