/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *                                                                              
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.             
 * ============================================================================
 */ 

/** ============================================================================
 *   @file  csl_cfgOpen.c
 *
 *   @path  $(CSLPATH)\src\cfg
 *
 *   @desc  File for functional layer of CSL API CSL_cfgOpen()
 *
 */

/* =============================================================================
 * Revision History
 * ===============
 *  11-Apr-2005 Brn Updated the file for doxygen compatibiliy
 *
 *  16-Nov-2005 ds Updated the documentation
 *
 *  31-Jan-2006 ds Supported to use the CSL_cfgGetBaseAddress() API
 *  08-Sep-2008 Update for Doxygen
 * =============================================================================
 */

#include <csl_cfg.h>

#pragma CODE_SECTION (CSL_cfgOpen, ".text:csl_section:cfg");
CSL_CfgHandle CSL_cfgOpen (
    CSL_CfgObj      *pCfgObj,
    CSL_InstNum      cfgNum,
    CSL_CfgParam    *pCfgParam,
    CSL_Status      *pStatus
)
{
    CSL_CfgHandle         hCfg = (CSL_CfgHandle)NULL;
    CSL_CfgBaseAddress    baseAddress;
    
    if (pStatus == NULL) {
        /* do nothing : already the module is initialized to NULL */    
    }
    
    else if (pCfgObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    
    else {
        *pStatus = CSL_cfgGetBaseAddress(cfgNum, pCfgParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pCfgObj->regs = baseAddress.regs;
            pCfgObj->cfgNum = (CSL_InstNum)cfgNum;
            hCfg = (CSL_CfgHandle)pCfgObj;
        }
        else {
            pCfgObj->regs = (CSL_CfgRegsOvly)NULL;
            pCfgObj->cfgNum = (CSL_InstNum)-1;
        }
    }
    return (hCfg);
}
