/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *   @file  csl_devGetBaseAddress.c
 *
 *   @path  $(CSLPATH)\src\dev
 *
 *   @desc  File for functional layer of CSL API @a CSL_devGetBaseAddress()
 *
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  06-Apr-2005 Sudeep File Created.
 *  25-Jan-2006 sd	   Modifications for the module name changes	
 *  09-Aug-2006 NG     Added condition to check the invalid parameter
 * =============================================================================
 */
#include <soc.h>
#include <cslr_dev.h>
#include <csl_dev.h>

/** ============================================================================
 * @n@b CSL_devGetBaseAddress
 *
 * @b Description
 * @n The get base address call will return the base address of the DEV module 
 *	  configuration registers.	
 *
 *   @b Arguments
 *   @verbatim      
            devNum          Specifies the instance of the DEV module

            pDevParam       Module specific parameters.
 
            pBaseAddress    Pointer to the base address structure to return the
                            base address details.
     @endverbatim
 *
 *   <b> Return Value </b>  CSL_Status
 *   @li                    CSL_SOK             Successful on getting the base 
 *                                              address of dev
 *   @li                    CSL_ESYS_FAIL       invalid instance number
 *   @li                    CSL_ESYS_INVPARAMS  Invalid parameter 
 *
 *   <b> Pre Condition </b>
 *   @n  None.
 *
 *   <b> Post Condition </b>
 *   @n  Base address structure is populated
 *
 *   @b Modifies
 *   @n   Base address structure.
 *
 *   @b Example
 *   @verbatim
        CSL_Status          status;
        CSL_DevBaseAddress  baseAddress;

       ...
       status = CSL_devGetBaseAddress(CSL_DEV, NULL, &baseAddress);

    @endverbatim
 *
 * ============================================================================
 */
#pragma CODE_SECTION (CSL_devGetBaseAddress, ".text:csl_section:dev");

CSL_Status CSL_devGetBaseAddress (
    CSL_InstNum 	      devNum,
    CSL_DevParam          *pDevParam,
    CSL_DevBaseAddress    *pBaseAddress
)
{
    CSL_Status status = CSL_SOK;

    if (pBaseAddress == NULL) {
        status = CSL_ESYS_INVPARAMS;
	}
    else {
        switch (devNum) {
            case CSL_DEV:
                pBaseAddress->regs = (CSL_DevRegsOvly)CSL_DEV_REGS;
                break;

            default:
                pBaseAddress->regs = (CSL_DevRegsOvly)NULL;
                status = CSL_ESYS_FAIL;
                break;
        }
    }
    return (status);
}

