/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found
 * in the license agreement under which this software has been supplied
 * ============================================================================
*/
/** ============================================================================
 *   @file  csl_memprotGetBaseAddress.c
 *
 *   @path  $(CSLPATH)\src\common
 *
 *   @desc  CSL Implementation of CSL_memprotGetBaseAddress
 *
 *   Note: This function is open for re-implementing if the user wants to modify
 *    the base address of the peripheral object to point to a different location
 *    there by allow CSL initiated write/reads into peripheral MMR's go to an 
 *    alternate location. Please refer documentation for more details. 
 *      
 *   @author Ruchika Kharwar.
 */
/* =============================================================================
 *  Revision History
 *  ================  
 * 22-sep-2005 PSK updated according to code review comments.
 * 09-Aug-2006 NG  Added condition to check the invalid parameter
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <soc.h>
#include <csl_memprot.h>


#pragma CODE_SECTION (CSL_memprotGetBaseAddress, ".text:csl_section:memprot");
CSL_Status CSL_memprotGetBaseAddress (
    CSL_InstNum               memprotNum,
    CSL_MemprotParam          *pMemprotParam,
    CSL_MemprotBaseAddress    *pBaseAddress 
)
{
    CSL_Status status = CSL_SOK;

    if (pBaseAddress == NULL) {
        status = CSL_ESYS_INVPARAMS;
	}
    else {
        switch (memprotNum) {
            case CSL_MEMPROT_L2:
                pBaseAddress->regs = (CSL_MemprotRegsOvly)CSL_MEMPROT_L2_REGS;
                break;

            case CSL_MEMPROT_L1D:
                pBaseAddress->regs = (CSL_MemprotRegsOvly)CSL_MEMPROT_L1D_REGS;
                break;

            case CSL_MEMPROT_L1P:
                pBaseAddress->regs = (CSL_MemprotRegsOvly)CSL_MEMPROT_L1P_REGS;
                break;

            default:
                pBaseAddress->regs = (CSL_MemprotRegsOvly)NULL;
                status = CSL_ESYS_FAIL;
                break;
        }
    }
    return (status);
}

