/*  ============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2008
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** @file csl_pscGetBaseAddress.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pscGetBaseAddress()
 *
 *  Description
 *    - The @a CSL_pscGetBaseAddress() function definition & it's associated functions
 *
 *  Path: \\(CSLPATH)\\src\\common
 */

/* =============================================================================
 * Revision History
 * ===============
 * 29-Jun-2006 TRR File Created.
 * 27-Oct-2008 Ported from old soc to new soc
 * =============================================================================
 */

#include <soc.h>
#include <csl_psc.h>

#pragma CODE_SECTION (CSL_pscGetBaseAddress, ".text:csl_section:psc");
CSL_Status CSL_pscGetBaseAddress (
    CSL_InstNum 	        pscNum,
    CSL_PscParam *          pPscParam,
    CSL_PscBaseAddress *    pBaseAddress
)
{
    CSL_Status st = CSL_SOK;

    pPscParam = pPscParam;

    if (pBaseAddress == NULL)
        return CSL_ESYS_INVPARAMS;

    switch (pscNum) {
    
    case CSL_PSC:
        pBaseAddress->regs = (CSL_PscRegsOvly)CSL_PSC_0_REGS;
        break;
    
    default:
        pBaseAddress->regs = (CSL_PscRegsOvly)NULL;
        st = CSL_ESYS_FAIL;
        break;
    }

    return st;
}

