/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 * Use of this software is controlled by the terms and conditions found
 * in the license agreement under which this software has been supplied
 * provided
 * ============================================================================
 */
/** ============================================================================
 *   @file  csl_tetbGetBaseAddress.c
 *
 *   @path  $(CSLPATH)\src\common
 *
 *   @desc  CSL Implementation of CSL_pwrdwnGetBaseAddress
 *
 *   Note: This function is open for re-implementing if the user wants to modify
 *    the base address of the peripheral object to point to a different location
 *    there by allow CSL initiated write/reads into peripheral MMR's go to an 
 *    alternate location. Please refer documentation for more details. 
 *
 *   @author Ruchika Kharwar.
 */
/* =============================================================================
 *  Revision History
 *  ================
 *   24-Apr-2008 File Created 
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <soc.h>
#include <csl_tetb.h>


#pragma CODE_SECTION (CSL_tetbGetBaseAddress, ".text:csl_section:tetb");
CSL_Status CSL_tetbGetBaseAddress (
    CSL_InstNum            tetbNum,
    CSL_TetbParam          *pTetbParam,
    CSL_TetbBaseAddress    *pBaseAddress 
)
{
    CSL_Status status = CSL_SOK;

    if (pBaseAddress == NULL)
        status = CSL_ESYS_INVPARAMS;
	else 
	{
        switch (tetbNum) 
		{
            case CSL_TETB:
                pBaseAddress->regs = (CSL_TetbRegsOvly)CSL_TETB_0_REGS;
                break;

            default:
                pBaseAddress->regs = (CSL_TetbRegsOvly)NULL;
                status = CSL_ESYS_FAIL;
        }
    }
    return (status);
}

