/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** 
 *  @file    csl_ddr2GetHwStatus.c
 *
 *  @brief   File for functional layer of CSL API @a CSL_ddr2GetHwStatus()
 *
 *  @path    $(CSLPATH)\src\ddr2
 *
 *  @desc
 *    - The @a CSL_ddr2GetHwStatus() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Created on: 12/4/2005
 *    - Reason: created the sources
 *
 *  @date 12th April, 2005
 *  @author Ramitha Mathew
 */
/*  ============================================================================
 *  Revision History
 *  ================
 *  30-May-2008 Removed CSL_DDR2_QUERY_IFRDY status query.
 *  08-Sep-2008 Update for Doxygen
 *  11-Nov-2008 Added query of CSL_DDR2_QUERY_IFRDY and CSL_DDR2_QUERY_DDRSLRATE 
 *              Removed query of CSL_DDR2_QUERY_SELF_REFRESH according to UG
 *  ============================================================================
 */

#include <csl_ddr2.h>
#include <csl_ddr2Aux.h>


#pragma CODE_SECTION (CSL_ddr2GetHwStatus,".text:csl_section:ddr2");
CSL_Status  CSL_ddr2GetHwStatus (
    CSL_Ddr2Handle           hDdr2,
    CSL_Ddr2HwStatusQuery    query,
    void                     *response
)
{
    CSL_Status status = CSL_SOK;
     
    if(hDdr2 == NULL) {
        status = CSL_ESYS_BADHANDLE;
        return status;
    }

    switch(query) {
        case CSL_DDR2_QUERY_REV_ID:
            CSL_ddr2GetRevId(hDdr2,(CSL_Ddr2ModIdRev *)response);
            break;        

        case CSL_DDR2_QUERY_REFRESH_RATE:
            *(Uint16 *)response = CSL_ddr2GetRefreshRate(hDdr2);
            break;

        case CSL_DDR2_QUERY_ENDIAN:
            CSL_ddr2GetEndian(hDdr2,(Uint8*)response);
            break; 
     
        case CSL_DDR2_QUERY_IFRDY:
            CSL_ddr2GetIFRDY(hDdr2,(Uint8*)response);
            break; 

        case CSL_DDR2_QUERY_DDRSLRATE:
            CSL_ddr2GetDdrslRate(hDdr2,(Uint8*)response);
            break; 
            
        default:
            status = CSL_ESYS_INVQUERY ;
            break;     
    }
    return status;
}

