/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** 
 *  @file    csl_ddr2HwControl.c
 *  
 *  @brief   File for functional layer of CSL API @a CSL_ddr2HwControl()
 *
 *  @path    $(CSLPATH)\src\ddr2
 *
 *  @desc
 *    - The @a CSL_ddr2HwControl() function definition & it's associated
 *      functions
 *
 *
 *  @date 11th April, 2005
 *  @author Ramitha Mathew.
 *
 */
/*  ============================================================================
 *  Revision History
 *  ================
 *   8-Sep-2008 Update for Doxygen
 *  11-Nov-2008 Removed config of CSL_DDR2_QUERY_SELF_REFRESH according to UG
 *  ============================================================================
 */

#include <csl_ddr2.h>
#include <csl_ddr2Aux.h>


#pragma CODE_SECTION (CSL_ddr2HwControl, ".text:csl_section:ddr2");
CSL_Status  CSL_ddr2HwControl (
    CSL_Ddr2Handle          hDdr2,
    CSL_Ddr2HwControlCmd    cmd,
    void                    *arg
)
{
    CSL_Status status = CSL_SOK;
    if(hDdr2 == NULL) {
        status = CSL_ESYS_BADHANDLE;
        return status;
    }

    switch(cmd) {
        case CSL_DDR2_CMD_REFRESH_RATE:
            CSL_ddr2RefreshRate(hDdr2,(*(Uint16*)arg));
            break;

        case CSL_DDR2_CMD_PRIO_RAISE:
            CSL_ddr2PrioRaise(hDdr2,(*(Uint8*)arg));
            break;      

        default:
            status = CSL_ESYS_INVCMD ;
            break;
    }
    return status;
}

