/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** 
 *  @file    csl_ddr2HwSetupRaw.c
 *
 *  @brief   File for functional layer of CSL API @a CSL_ddr2HwSetupRaw()
 *
 *  @path:   $(CSLPATH)\src\ddr2
 *
 *  @desc
 *    - The @a CSL_ddr2HwSetupRaw() function definition & it's associated 
 *      functions
 *
 *  Modification 1
 *    - Modified on: 12/4/2005
 *    - Reason: created the sources
 *
 *  @date 12th April, 2005
 *  @author Ramitha Mathew.
 *
 */

/*  ============================================================================
 *  Revision History
 *  ================
 *  30-May-2008 Updated SDCFG register bit field names according to UG.
 *  26-Mar-2008 Lock the BOOT_UNLOCK bit to prevent from making further changes.
 *  08-Sep-2008 Update for Doxygen
 *  11-Nov-2008 Ported from Faraday.
 *  ============================================================================
 */
 
#include <csl_ddr2.h>


#pragma CODE_SECTION (CSL_ddr2HwSetupRaw, ".text:csl_section:ddr2");
CSL_Status  CSL_ddr2HwSetupRaw (
    CSL_Ddr2Handle    hDdr2,
    CSL_Ddr2Config    *config
)
{
    Uint32 tmpReg;  
    if(hDdr2 == NULL) {
        return CSL_ESYS_BADHANDLE;
    }

    if(config == NULL) {
        return CSL_ESYS_INVPARAMS;
    }
        
    /* Disabling the Initialization sequence. */
    
    /* setting the SDRAM Config Register */
    /* The mask is used to leave the reserved fields at their default values */
    /* Unlock boot and timing fields */
    tmpReg = hDdr2->regs->SDCFG;
    CSL_FINST(tmpReg, DDR2_SDCFG_BOOT_UNLOCK, UNLOCKED);
	CSL_FINST(tmpReg, DDR2_SDCFG_TIMUNLOCK, SET);
	hDdr2->regs->SDCFG = tmpReg;

    /* setting SDRAM Timing1 Register */
    hDdr2->regs->SDTIM1 = config->SDTIM1;
    
    /* setting the SDRAM Timing2 Register */
    hDdr2->regs->SDTIM2 = config->SDTIM2;
    
    /* Set the read latency */
	hDdr2->regs->DMCCTL = config->DMCCTL;   
                               
    /* setting the SDRAM Refresh Control Register */
    hDdr2->regs->SDRFC = config->SDRFC;     
    
    /* setting the VBUSM Burst Priority Register */
    hDdr2->regs->BPRIO = config->BPRIO;

    /* Lock the BOOT_UNLOCK bit to prevent from making further changes */   
    hDdr2->regs->SDCFG = (config->SDCFG & (~(CSL_DDR2_SDCFG_BOOT_UNLOCK_MASK))); 
 
	/* Lock the BOOT_UNLOCK bit to prevent from making further changes */
    //CSL_FINS(hDdr2->regs->SDCFG,DDR2_SDCFG_TIMUNLOCK, CSL_DDR2_SDCFG_TIMUNLOCK_CLEAR );
	CSL_FINST(hDdr2->regs->SDCFG,DDR2_SDCFG_TIMUNLOCK, CLEAR );
    
    return CSL_SOK;
}

