/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** 
 *  @file    csl_ddr2Open.c
 *  
 *  @brief   File for functional layer of CSL API @a CSL_ddr2Open()
 *
 *  @path:   $(CSLPATH)\src\ddr2
 *
 *  @desc
 *    - The @a CSL_ddr2Open() function definition & it's associated functions
 *
 *  Modification 1
 *    - Created on: 10/04/2005
 *    - Reason:       Created the sources.
 *
 *  @date 10th April, 2005
 *  @author Ramitha Mathew.
 *
 *  08-Sep-2008 Update for Doxygen
 */
/* ===============================================================================
 *  Revision History
 *  ===============
 *  10-Apr-2005 File Created
 *  08-Sep-2008 Update for Doxygen
 *
 * ===============================================================================
 */
#include <csl_ddr2.h>


#pragma CODE_SECTION (CSL_ddr2Open, ".text:csl_section:ddr2");
CSL_Ddr2Handle CSL_ddr2Open (
    CSL_Ddr2Obj      *pDdr2Obj,
    CSL_InstNum      ddr2Num,
    CSL_Ddr2Param    *pDdr2Param,
    CSL_Status       *pStatus
)
{    
    CSL_Status             status = CSL_SOK;
    CSL_Ddr2Handle         hDdr2;
    CSL_Ddr2BaseAddress    baseAddress;
    
    *pDdr2Param          = *pDdr2Param;
    
    if (pDdr2Obj == NULL) {
        return NULL;
    }
        
    status = CSL_ddr2GetBaseAddress(ddr2Num, pDdr2Param, &baseAddress);

    if (status == CSL_SOK) {
        pDdr2Obj->regs = baseAddress.regs;
        pDdr2Obj->perNum = (CSL_InstNum)ddr2Num;
        hDdr2 = (CSL_Ddr2Handle)pDdr2Obj;
    } 
    else {
        pDdr2Obj->regs = (CSL_Ddr2RegsOvly)NULL;
        pDdr2Obj->perNum = (CSL_InstNum)-1;
        hDdr2 = (CSL_Ddr2Handle)NULL;
    }

    if (pStatus != NULL) {
        *pStatus = status;
    }
    return hDdr2;
}

