/*  ===========================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *  Use of this software is controlled by the terms and conditions found
 *  in the license agreement under which this software has been supplied
 *  provided
 *
 *  ===========================================================================
 */
 
 /** ============================================================================
 *   @file  csl_edcGetErrorAddress.c
 *
 *   @path  $(CSLPATH)\src\edc
 *
 *   @desc  File for functional layer of CSL API CSL_edcGetErrorAddress ()
 *
 */
 
/* =============================================================================
 *  Revision History
 *  ===============
 *  08-Jul-2004 Chad Courtney  File created.
 *
 *  02-Sept-2005 ds            modified.
 *  
 *  09-Dec-2005  ds            - Updated getting error address for L2 to return 
 *                               the bitposition.
 *                             - Changed returned adrdess to left shifted by 
 *                               5 bits 
 *  08-Sep-2008 Update for Doxygen
 * =============================================================================
 */

#include <csl_edc.h>

#pragma CODE_SECTION (CSL_edcGetErrorAddress, ".text:csl_section:edc");
CSL_Status  CSL_edcGetErrorAddress (
    CSL_EdcMem          edcMem,
    CSL_EdcAddrInfo     *edcAddr
)
{
    CSL_Status status = CSL_SOK;
    Uint32     addr;

    if (edcAddr == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (edcMem) {
            /* Get Address Information for L2 Error */
            case CSL_EDC_L2:       
                addr = (Uint32) CSL_FEXT(((CSL_EdcRegs*)CSL_EDC_0_REGS)->L2EDADDR, \
                                      EDC_L2EDADDR_ADDR); 
                edcAddr->addr = addr << 5; /* 5 LSBs assumed to be 0 */

                edcAddr->l2way = (CSL_EdcAddrL2way) \
                    CSL_FEXT(((CSL_EdcRegs*)CSL_EDC_0_REGS)->L2EDADDR, \
                            EDC_L2EDADDR_L2WAY);
                edcAddr->sram  = (CSL_EdcAddrSram) \
                    CSL_FEXT(((CSL_EdcRegs*)CSL_EDC_0_REGS)->L2EDADDR, \
                            EDC_L2EDADDR_SRAM);
                edcAddr->bitPos = (Uint8) 
                    CSL_FEXTR(((CSL_EdcRegs*)CSL_EDC_0_REGS)->L2EDSTAT, 20,16);
                edcAddr->word32Bit = (Uint8) 
                    CSL_FEXTR(((CSL_EdcRegs*)CSL_EDC_0_REGS)->L2EDSTAT, 23, 21);
            break;

            /* Get Address Information for L1P Error */
            case CSL_EDC_L1P:        
                addr = (Uint32)CSL_FEXT(((CSL_EdcRegs*)CSL_EDC_0_REGS)->L1PEDADDR, \
                            EDC_L1PEDADDR_ADDR);
                edcAddr->addr = addr << 5; /* 5 LSBs assumed to be 0 */

                edcAddr->sram = (CSL_EdcAddrSram) \
                    CSL_FEXT(((CSL_EdcRegs*)CSL_EDC_0_REGS)->L1PEDADDR, \
                            EDC_L1PEDADDR_SRAM);        
            break;

            default:
                status = CSL_ESYS_INVPARAMS;         
        }
    }
    return (status);    
}
