/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  csl_edma3ChannelOpen.c
 *
 *   @path  $(CSLPATH)\src\edma
 *
 *   @desc  EDMA3 CSL Implementation on DSP side
 *
 */

/* =============================================================================
 * Revision History
 * ================
 * 02-May-2008 New file created
 * 08-Sep-2008 Update for Doxygen
 * =============================================================================
 */

#include <csl_edma3.h>


#pragma CODE_SECTION (CSL_edma3ChannelOpen, ".text:csl_section:edma3");
CSL_Edma3ChannelHandle  CSL_edma3ChannelOpen (
    CSL_Edma3ChannelObj     *pEdmaObj,
    CSL_InstNum             edmaNum,
    CSL_Edma3ChannelAttr    *pChAttr,
    CSL_Status              *pStatus
)
{
    CSL_Edma3ChannelHandle        hEdma = (CSL_Edma3ChannelHandle)NULL;
    CSL_Edma3ModuleBaseAddress    baseAddress;
    
    if (pStatus == NULL) {
        /* Do nothing : Module handle already initialised to NULL */
    }
    else if (pEdmaObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else {
        if (pChAttr != NULL) {
            *pStatus = CSL_edma3ccGetModuleBaseAddr(edmaNum, NULL, &baseAddress);
            if (*pStatus == CSL_SOK) {
                pEdmaObj->regs = baseAddress.regs;
                pEdmaObj->edmaNum = edmaNum;
                pEdmaObj->chaNum = pChAttr->chaNum;
                pEdmaObj->region = pChAttr->regionNum;
                hEdma = (CSL_Edma3ChannelHandle)pEdmaObj;
            }
            else {
                pEdmaObj->regs = (CSL_Edma3ccRegsOvly)NULL;
                pEdmaObj->edmaNum = (CSL_InstNum) -1;
                pEdmaObj->chaNum = -1;
                pEdmaObj->region = -2;
            } 
        }
        else {
            *pStatus = CSL_ESYS_INVPARAMS;
        }        
    }

    return (hEdma);
}

