/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_edma3GetHwSetup.c
 *
 *   @path  $(CSLPATH)\src\edma
 *
 *   @desc  EDMA3 CSL Implementation on DSP side
 *
 */

/* =============================================================================
 * Revision History
 * ================
 * 02-May-2008 New file created
 * 08-Sep-2008 Update for Doxygen
 * =============================================================================
 */

#include <csl_edma3.h>
#include <csl_edma3Aux.h>


#pragma CODE_SECTION (CSL_edma3GetHwSetup, ".text:csl_section:edma3");
CSL_Status  CSL_edma3GetHwSetup (
    CSL_Edma3Handle        hMod,
    CSL_Edma3HwSetup      *setup
)
{
    Uint32        numCha;
    Uint32        tempQnum  = 0;
    Uint32        tempChmap = 0;
    Uint32        ii = 0;
    CSL_Status    status = CSL_SOK;  
    
    if (hMod == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        if (setup->dmaChaSetup != NULL) {
            for (numCha = 0 ; numCha < CSL_EDMA3_NUM_DMACH; numCha++) {
#ifdef CSL_EDMA3_CHMAPEXIST
                setup->dmaChaSetup[numCha].paramNum = \
                    CSL_FEXT(hMod->regs->DCHMAP[numCha], EDMA3CC_DCHMAP_PAENTRY);
#endif      
                if (((ii) % 8) == 0)
                    tempQnum = hMod->regs->DMAQNUM[numCha/8];
                ii = numCha % 8;
                setup->dmaChaSetup[numCha].que = \
                      (CSL_Edma3Que) CSL_FEXTR(tempQnum, (ii * 4) + 2, (ii * 4));
            }
        }
        
        if (setup->qdmaChaSetup != NULL) { 
            tempQnum = hMod->regs->QDMAQNUM;
            for (numCha = 0 ; numCha < CSL_EDMA3_NUM_QDMACH; numCha++) {
                tempChmap = hMod->regs->QCHMAP[numCha];
                setup->qdmaChaSetup[numCha].paramNum = \
                        CSL_FEXT(tempChmap,EDMA3CC_QCHMAP_PAENTRY);
                setup->qdmaChaSetup[numCha].triggerWord = \
                      CSL_FEXT(tempChmap,EDMA3CC_QCHMAP_TRWORD);
                setup->qdmaChaSetup[numCha].que = \
                     (CSL_Edma3Que)CSL_FEXTR(tempQnum, (numCha * 4) + 2, numCha* 4);
            }
        }
    }

    return (status); 
}

