/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_edma3GetHwStatus.c
 *
 *   @path  $(CSLPATH)\src\edma
 *
 *   @desc  File for functional layer of CSL API @a CSL_edma3GetHwStatus()
 *
 */
 
/* =============================================================================
 * Revision History
 * ================
 * 02-May-2008 New file created
 * 08-Sep-2008 Update for Doxygen
 * =============================================================================
 */

#include <csl_edma3.h>
#include <csl_edma3Aux.h>


#pragma CODE_SECTION (CSL_edma3GetHwStatus, ".text:csl_section:edma3");
CSL_Status  CSL_edma3GetHwStatus (
    CSL_Edma3Handle                hMod,
    CSL_Edma3HwStatusQuery         myQuery,
    void                           *response
)
{
    CSL_Status status = CSL_SOK;
    
    if (hMod == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch(myQuery) {
#if CSL_EDMA3_MEMPROTECT        
            case CSL_EDMA3_QUERY_MEMFAULT:  
                status = CSL_edma3GetMemoryFaultError(hMod, \
                                             (CSL_Edma3MemFaultStat*)response);
                break;  
            case CSL_EDMA3_QUERY_MEMPROTECT:    
                ((CSL_Edma3CmdRegion*)response)->regionVal = \
                    CSL_edma3GetMemoryProtectionAttrib(hMod, \
                                      ((CSL_Edma3CmdRegion*)response)->region);
                break;              
#endif              
            case CSL_EDMA3_QUERY_CTRLERROR: 
                status = CSL_edma3GetControllerError(hMod, \
                                              (CSL_Edma3CtrlErrStat*)response);
                break;          
            case CSL_EDMA3_QUERY_INTRPEND:  
                status = CSL_edma3GetIntrPendStatus(hMod, \
                                       ((CSL_Edma3CmdIntr*)response)->region, \
                                       &((CSL_Edma3CmdIntr*)response)->intr, \
                                       &((CSL_Edma3CmdIntr*)response)->intrh );
                break;          
            
            case CSL_EDMA3_QUERY_EVENTMISSED:   
                status = \
                CSL_edma3GetEventMissed(hMod,&((CSL_BitMask32*)response)[0],\
                                        &((CSL_BitMask32*)response)[1], \
                                        &((CSL_BitMask32*)response)[2]);
                break;   
            case CSL_EDMA3_QUERY_QUESTATUS: 
                status = \
                CSL_edma3GetQueStatus(hMod,((CSL_Edma3QueStat*)response)->que,\
                                     ((CSL_Edma3QueStat*)response));
                break;  
            case CSL_EDMA3_QUERY_ACTIVITY:
                status = \
                CSL_edma3GetActivityStatus(hMod,\
                                           ((CSL_Edma3ActivityStat*)response));
                break;
            case  CSL_EDMA3_QUERY_INFO:
                status = CSL_edma3GetInfo(hMod,((CSL_Edma3QueryInfo*)response));
                break;
            default:
                status = CSL_ESYS_INVQUERY;
                break; 
        }  
    }

    return (status);
}

