/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_edma3HwChannelControl.c
 *
 *   @path  $(CSLPATH)\src\edma
 *
 *   @desc  File for functional layer of CSL API CSL_edma3HwChannelControl()
 *
 */

/* =============================================================================
 * Revision History
 * ================
 * 02-May-2008 New file created
 * 08-Sep-2008 Update for Doxygen
 * =============================================================================
 */

 
#include <csl_edma3.h>
#include <csl_edma3Aux.h>


#pragma CODE_SECTION (CSL_edma3HwChannelControl, ".text:csl_section:edma3");
CSL_Status  CSL_edma3HwChannelControl (
    CSL_Edma3ChannelHandle          hCh,
    CSL_Edma3HwChannelControlCmd    cmd,
    void                            *cmdArg
)
{ 
    CSL_Status    status = CSL_SOK;
    
    if (hCh == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if ((cmd == CSL_EDMA3_CMD_CHANNEL_CLEARERR) && (cmdArg == NULL)) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch(cmd) {
            case CSL_EDMA3_CMD_CHANNEL_ENABLE:
                status = CSL_edma3ChannelEnable(hCh);
                break;
            
            case CSL_EDMA3_CMD_CHANNEL_DISABLE:
                status = CSL_edma3ChannelDisable(hCh);
                break;
            
            case CSL_EDMA3_CMD_CHANNEL_SET:
                status = CSL_edma3ChannelEventSet(hCh);
                break;
            
            case CSL_EDMA3_CMD_CHANNEL_CLEAR:
                status = CSL_edma3ChannelEventClear(hCh);
                break;          
            
            case CSL_EDMA3_CMD_CHANNEL_CLEARERR:
                status = CSL_Edma3ChannelErrorClear(hCh,
                                                 (CSL_Edma3ChannelErr*)cmdArg);
                break;
            
            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }

    return (status);
}

