/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_edma3HwControl.c
 *
 *   @path  $(CSLPATH)\src\edma
 *
 *   @desc  File for functional layer of CSL API CSL_edma3HwControl()
 *
 */
 
/* =============================================================================
 * Revision History
 * ================
 * 02-May-2008 New file created
 * 08-Sep-2008 Update for Doxygen
 * =============================================================================
 */
 
#include <csl_edma3.h>
#include <csl_edma3Aux.h> 


#pragma CODE_SECTION (CSL_edma3HwControl, ".text:csl_section:edma3");
CSL_Status  CSL_edma3HwControl (
    CSL_Edma3Handle           hMod,
    CSL_Edma3HwControlCmd     cmd,
    void                     *cmdArg
)
{ 
    CSL_Status    status = CSL_SOK; 
    
    if (hMod == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (((cmd >= 0) && (cmd <= CSL_EDMA3_CMD_EVENTMISSED_CLEAR)) && 
              ((cmd != CSL_EDMA3_CMD_MEMFAULT_CLEAR) && 
               (cmd != CSL_EDMA3_CMD_ERROR_EVAL)) && (cmdArg == NULL)) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch(cmd) {
#if CSL_EDMA3_MEMPROTECT    
            case CSL_EDMA3_CMD_MEMPROTECT_SET:
                status = CSL_edma3SetMemoryProtectionAttrib(hMod, \
                                     ((CSL_Edma3CmdRegion*)cmdArg)->region,\
                                     ((CSL_Edma3CmdRegion*)cmdArg)->regionVal);
                break;
            case CSL_EDMA3_CMD_MEMFAULT_CLEAR:
                status = CSL_edma3MemFaultClear(hMod);
                break;
#endif                      
            case CSL_EDMA3_CMD_DMAREGION_ENABLE:
                status = CSL_edma3DmaRegionAccessEnable(hMod, \
                                     ((CSL_Edma3CmdDrae*)cmdArg)->region, \
                                     ((CSL_Edma3CmdDrae*)cmdArg)->drae, \
                                     ((CSL_Edma3CmdDrae*)cmdArg)->draeh);
                break;
                
            case CSL_EDMA3_CMD_DMAREGION_DISABLE:
                status = CSL_edma3DmaRegionAccessDisable(hMod, \
                                     ((CSL_Edma3CmdDrae*)cmdArg)->region, \
                                     ((CSL_Edma3CmdDrae*)cmdArg)->drae, \
                                     ((CSL_Edma3CmdDrae*)cmdArg)->draeh);
                break;
                
            case CSL_EDMA3_CMD_QDMAREGION_ENABLE:
                status = CSL_edma3QdmaRegionAccessEnable(hMod, \
                                     ((CSL_Edma3CmdQrae*)cmdArg)->region,\
                                     ((CSL_Edma3CmdQrae*)cmdArg)->qrae);
                break;
                
            case CSL_EDMA3_CMD_QDMAREGION_DISABLE:
                status = CSL_edma3QdmaRegionAccessDisable(hMod, \
                                     ((CSL_Edma3CmdQrae*)cmdArg)->region, \
                                     ((CSL_Edma3CmdQrae*)cmdArg)->qrae);
                break;  
                
            case CSL_EDMA3_CMD_QUEPRIORITY_SET:
                status = CSL_edma3EventQueuePrioritySet(hMod, \
                                     ((CSL_Edma3CmdQuePri*)cmdArg)->que, \
                                     ((CSL_Edma3CmdQuePri*)cmdArg)->pri);
                break;
                
            case CSL_EDMA3_CMD_QUETHRESHOLD_SET:
                status = CSL_edma3EventQueueThresholdSet(hMod,\
                                     ((CSL_Edma3CmdQueThr*)cmdArg)->que, \
                                     ((CSL_Edma3CmdQueThr*)cmdArg)->threshold);
                break;          
                
            case CSL_EDMA3_CMD_ERROR_EVAL:
                status = CSL_edma3ErrorEval(hMod);
                break;          
                
            case CSL_EDMA3_CMD_INTRPEND_CLEAR:
                status = CSL_edma3InterruptClear(hMod, \
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->region, \
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->intr,\
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->intrh);
                break;          
                
            case CSL_EDMA3_CMD_INTR_ENABLE:
                status = CSL_edma3InterruptEnable(hMod, \
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->region, \
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->intr, \
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->intrh);
                break;          
                
            case CSL_EDMA3_CMD_INTR_DISABLE:
                status = CSL_edma3InterruptDisable(hMod, \
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->region, \
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->intr, \
                                     ((CSL_Edma3CmdIntr*)(cmdArg))->intrh);
                break;
                
            case CSL_EDMA3_CMD_INTR_EVAL:
                status = CSL_edma3InterruptEval(hMod,*((Int*)(cmdArg)));            
                break;  
                        
            case CSL_EDMA3_CMD_CTRLERROR_CLEAR:
                status = CSL_edma3ControllerErrorClear(hMod, \
                ((CSL_Edma3CtrlErrStat*)(cmdArg)));
                break;
                
            case CSL_EDMA3_CMD_EVENTMISSED_CLEAR:
                status = \
                CSL_edma3EventsMissedClear(hMod,((CSL_BitMask32*)cmdArg)[0], \
                ((CSL_BitMask32*)cmdArg)[1],((CSL_BitMask32*)cmdArg)[2]);
                break;
                
            default:
                 status = CSL_ESYS_INVCMD;
                 break;
        }
    }

    return (status);
}

