/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_edma3HwSetup.c
 *
 *   @path  $(CSLPATH)\src\edma
 *
 *   @desc  File for functional layer of CSL API CSL_edma3HwSetup()
 *
 */
 
/* =============================================================================
 * Revision History
 * ================
 * 02-May-2008 New file created
 * 08-Sep-2008 Update for Doxygen
 * =============================================================================
 */

#include <csl_edma3.h>
#include <csl_edma3Aux.h>


#pragma CODE_SECTION (CSL_edma3HwSetup, ".text:csl_section:edma3");
CSL_Status  CSL_edma3HwSetup(
    CSL_Edma3Handle        hMod,
    CSL_Edma3HwSetup       *setup
)
{
    Uint32        numCha;
    Uint32        tempQnum = 0;
    Uint32        tempChmap = 0;
    Uint32        ii;
    CSL_Status    status = CSL_SOK;
    
    if (hMod == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }    
    else if (setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        if (setup->dmaChaSetup != NULL) {
            for (numCha = 0 ; numCha < CSL_EDMA3_NUM_DMACH; numCha++) {
#ifdef CSL_EDMA3_CHMAPEXIST
                hMod->regs->DCHMAP[numCha] = 
                    CSL_FMK(EDMA3CC_DCHMAP_PAENTRY, \
                              setup->dmaChaSetup[numCha].paramNum);
#endif              
                ii = numCha % 8;
                CSL_FINSR(tempQnum,(ii * 4) + 2,(ii * 4), \
                          setup->dmaChaSetup[numCha].que);
                if (((ii + 1) % 8) == 0) {
                    hMod->regs->DMAQNUM[numCha/8] = tempQnum;
                    tempQnum = 0;
                }
            }
        }
        
        if (setup->qdmaChaSetup != NULL) { 
            for (numCha = 0 ; numCha < CSL_EDMA3_NUM_QDMACH; numCha++) {
                tempChmap = CSL_FMK(EDMA3CC_QCHMAP_PAENTRY, \
                                    setup->qdmaChaSetup[numCha].paramNum)| \
                            CSL_FMK(EDMA3CC_QCHMAP_TRWORD, \
                                    setup->qdmaChaSetup[numCha].triggerWord);
                hMod->regs->QCHMAP[numCha] = tempChmap;
                CSL_FINSR(tempQnum, (numCha * 4) + 2,(numCha * 4), \
                            setup->qdmaChaSetup[numCha].que);
            }
            
            hMod->regs->QDMAQNUM = tempQnum;
        }
    }

    return (status); 
}

