/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  csl_edma3Param.c
 *
 *   @path  $(CSLPATH)\src\edma
 *
 *   @desc  CSL for  Edma Parameter Entries
 *
 */
 
/* =============================================================================
 * Revision History
 * ================
 * 02-May-2008 New file created
 * 08-Sep-2008 Update for Doxygen
 * =============================================================================
 */
 
#include <csl_edma3.h>

/* ============================================================================
 *    CSL_edma3GetParamHandle
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_edma3GetParamHandle, ".text:csl_section:edma3");
CSL_Edma3ParamHandle  CSL_edma3GetParamHandle (
    CSL_Edma3ChannelHandle    hEdma,
    Int16                     paramNum,
    CSL_Status                *status       
)
{   
    CSL_Edma3ParamHandle handle = (CSL_Edma3ParamHandle)NULL;

    if (status == NULL) {
        /* Do nothing */
    }
    else if (hEdma == NULL) {
        *status = CSL_ESYS_BADHANDLE;
    }
    else if (paramNum < 0 || (paramNum >= CSL_EDMA3_NUM_PARAMSETS)) {
        *status = CSL_ESYS_INVPARAMS;
    }
    else {
        handle = (&hEdma->regs->PARAMSET[paramNum]);
        *status = CSL_SOK;
    }

    return (handle);
}

/* ============================================================================
 *    CSL_edma3ParamSetup
 * =============================================================================
 */

#pragma CODE_SECTION (CSL_edma3ParamSetup, ".text:csl_section:edma3");
CSL_Status  CSL_edma3ParamSetup (
    CSL_Edma3ParamHandle       hParamHndl,
    CSL_Edma3ParamSetup        *setup
)
{
    Uint32        *paramHndl = (Uint32*)hParamHndl;
    Uint32        i;
    CSL_Status    status = CSL_SOK;
    
    if (hParamHndl == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        for (i = 0; i < 8 ; i++)
            paramHndl[i] = ((Uint32*)setup)[i];  
    }

    return (status);
}

/* ============================================================================
 *    CSL_edma3ParamWriteWord
 * =============================================================================
 */
 
#pragma CODE_SECTION (CSL_edma3ParamWriteWord, ".text:csl_section:edma3");
CSL_Status  CSL_edma3ParamWriteWord(
    CSL_Edma3ParamHandle       hParamHndl,
    Uint16                     wordOffset,
    Uint32                     word 
)
{
    Uint32        *hParam = (Uint32*)(hParamHndl);
    CSL_Status    status = CSL_SOK;
    
    if (hParamHndl == NULL)
        status = CSL_ESYS_BADHANDLE;
    else    
        hParam[wordOffset] = word;  
    
    return (status);
}

