/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *  @file    csl_emifaGetHwSetup.c
 *
 *  @path    $(CSLPATH)\src\emifa
 *
 *  $desc    File for functional layer of CSL API @a CSL_emifaGetHwSetup()
 *           - The @a CSL_emifaGetHwSetup() function definition & it's 
 *             associated functions
 *
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  12-May-2005 RM  File Created.
 *  
 *  09-Sep-2005 NG  Updation according to coding guidelines
 *  08-Sep-2008 Update for Doxygen
 *  
 * =============================================================================
 */
#include <csl_emifa.h>


#pragma CODE_SECTION (CSL_emifaGetHwSetup, ".text:csl_section:emifa")
CSL_Status  CSL_emifaGetHwSetup (
    CSL_EmifaHandle     hEmifa,
    CSL_EmifaHwSetup    *setup
)
{
    Uint8 loop;
    volatile Uint32* ceCfgBaseAddr=0;
    CSL_Status status = CSL_SOK;
    
    /* invalid parameter checking */
    if (setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else if (hEmifa == NULL) {
        /* bad handle checking */
        status = CSL_ESYS_BADHANDLE;
    }    
    else {
        /* Get Async config */
        if (setup->asyncWait != NULL) {
            setup->asyncWait->asyncRdyPol = 
                 (CSL_EmifaArdyPol)CSL_FEXT(hEmifa->regs->AWCC, EMIFA_AWCC_AP);
            setup->asyncWait->turnArnd = 
                 (Uint8)CSL_FEXT(hEmifa->regs->AWCC, EMIFA_AWCC_TA);    
            setup->asyncWait->maxExtWait = 
                 (Uint8)CSL_FEXT(hEmifa->regs->AWCC, EMIFA_AWCC_MAX_EXT_WAIT);
        }

        ceCfgBaseAddr = &(hEmifa->regs->CE2CFG);

        for (loop=0; loop < NUMCHIPENABLE; loop++) {
            if (setup->ceCfg[loop] != NULL)
            {
                if ((setup->ceCfg[loop]->ssel == 0) && 
                    (setup->ceCfg[loop]->async != NULL) &&
                    (!((Uint8)CSL_FEXT(*(ceCfgBaseAddr + loop), 
                                          EMIFA_CE2CFG_SSEL))))
                {      
                    setup->ceCfg[loop]->async->selectStrobe = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_SS);
                    setup->ceCfg[loop]->async->weMode = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_BWEM);    
                    setup->ceCfg[loop]->async->asyncRdyEn = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_AE);
                    setup->ceCfg[loop]->async->wSetup = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_W_SETUP);
                    setup->ceCfg[loop]->async->wStrobe = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_W_STROBE);    
                    setup->ceCfg[loop]->async->wHold = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_W_HOLD);
                    setup->ceCfg[loop]->async->rSetup = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_R_SETUP);
                    setup->ceCfg[loop]->async->rStrobe = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_R_STROBE);    
                    setup->ceCfg[loop]->async->rHold = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_R_HOLD);
                    setup->ceCfg[loop]->async->asize = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_ASIZE);      
                }

                if ((setup->ceCfg[loop]->ssel == 1) && 
                    (setup->ceCfg[loop]->sync != NULL) &&
                    ((Uint8)CSL_FEXT(*(ceCfgBaseAddr + loop), EMIFA_CE2CFG_SSEL)))
                {
                    setup->ceCfg[loop]->sync->readByteEn = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_RD_BE_EN);
                    setup->ceCfg[loop]->sync->chipEnExt = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_CE_EXT);    
                    setup->ceCfg[loop]->sync->readEn = (Uint8)CSL_FEXT(
                        *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_R_ENABLE);
                    setup->ceCfg[loop]->sync->w_ltncy = (Uint8)CSL_FEXT(
                            *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_W_LTNCY);
                    setup->ceCfg[loop]->sync->r_ltncy = (Uint8)CSL_FEXT(
                            *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_R_LTNCY);  
                    setup->ceCfg[loop]->sync->sbsize = (Uint8)CSL_FEXT(
                            *(ceCfgBaseAddr + loop), EMIFA_CE2CFG_SBSIZE);                
                }      
                else {
                    status = CSL_ESYS_FAIL;
                }  
            }
        }
    }
    
    return (status);
}

