/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *  @file    csl_emifaGetHwStatus.c
 *
 *  @path    $(CSLPATH)\src\emifa
 *
 *  $desc    File for functional layer of CSL API @a CSL_emifaGetHwStatus()
 *           - The @a CSL_emifaGetHwStatus() function definition & it's 
 *             associated functions
 *
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  12-May-2005 RM  File Created.
 *  
 *  09-Sep-2005 NG  Updation according to coding guidelines
 *  08-Sep-2008 Update for Doxygen
 *  
 * =============================================================================
 */
#include <csl_emifa.h>
#include <csl_emifaAux.h>


#pragma CODE_SECTION (CSL_emifaGetHwStatus,".text:csl_section:emifa");
CSL_Status  CSL_emifaGetHwStatus (
    CSL_EmifaHandle           hEmifa,
    CSL_EmifaHwStatusQuery    query,
    void                      *response
)
{
    CSL_Status status = CSL_SOK;
     
    if(hEmifa == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (query) {
            case CSL_EMIFA_QUERY_REV_ID:
                CSL_emifaGetRevId (hEmifa,(CSL_EmifaModIdRev *)response);
                break; 
            case CSL_EMIFA_QUERY_ASYNC_TIMEOUT_EN:
                *(Uint8 *)response = CSL_emifaGetAsyncEnStatus (hEmifa);
                break;  
            case CSL_EMIFA_QUERY_ASYNC_TIMEOUT_STATUS:
                *(Uint8 *)response = CSL_emifaGetAsyncStatus (hEmifa);
                break;                
            case CSL_EMIFA_QUERY_ENDIAN:
                CSL_emifaGetEndian (hEmifa,(Uint8*)response);
                break;                           
            default:
                status = CSL_ESYS_INVQUERY ;
                break;
        }
    }
    
    return (status);
}

