/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *  @file    csl_emifaHwControl.c
 *  
 *  @path    $(CSLPATH)\src\emifa
 *
 *  $desc    File for functional layer of CSL API @a CSL_emifaHwControl()
 *           - The @a CSL_emifaHwControl() function definition & it's associated
 *             functions
 *
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  12-May-2005 RM  File Created.
 *  
 *  09-Sep-2005 NG  Updation according to coding guidelines
 *  08-Sep-2008 Update for Doxygen
 *  
 * =============================================================================
 */
#include <csl_emifa.h>
#include <csl_emifaAux.h>

     
#pragma CODE_SECTION (CSL_emifaHwControl, ".text:csl_section:emifa");
CSL_Status  CSL_emifaHwControl (
    CSL_EmifaHandle          hEmifa,
    CSL_EmifaHwControlCmd    cmd,
    void                     *arg
)
{
    CSL_Status status = CSL_SOK;

    if(hEmifa == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if ((cmd == CSL_EMIFA_CMD_PRIO_RAISE) && (arg == NULL)) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch(cmd) {
            case CSL_EMIFA_CMD_ASYNC_TIMEOUT_CLEAR:
                CSL_emifaAsyncClear (hEmifa);
                break;
            case CSL_EMIFA_CMD_ASYNC_TIMEOUT_DISABLE:
                CSL_emifaAsyncDisable (hEmifa);    
                break;
            case CSL_EMIFA_CMD_ASYNC_TIMEOUT_ENABLE:
                CSL_emifaAsyncEnable (hEmifa);
                break;         
            case CSL_EMIFA_CMD_PRIO_RAISE:
                CSL_emifaPrioRaise (hEmifa,(*(Uint8*)arg));
                break;        
            default:
                status = CSL_ESYS_INVCMD ;
                break;
        }
    }
    
    return (status);
}

