/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *  @file    csl_emifaHwSetupRaw.c
 *
 *  @path    $(CSLPATH)\src\emifa
 *
 *  @desc    File for functional layer of CSL API @a CSL_emifaHwSetupRaw()
 *           - The @a CSL_emifaHwSetupRaw() function definition & it's 
 *             associated  functions
 *
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  12-May-2005 RM  File Created.
 *  
 *  12-Jul-2005 RM - Changed the module name from EMIF64 to EMIFA            
 *                 - Changes made in accordance to the change in cslr_emifa.h        
 *                                
 *  09-Sep-2005 NG  Updation according to coding guidelines
 *  08-Sep-2008 Update for Doxygen
 *  
 * =============================================================================
 */
#include <csl_emifa.h>


#pragma CODE_SECTION (CSL_emifaHwSetupRaw, ".text:csl_section:emifa");
CSL_Status  CSL_emifaHwSetupRaw (
    CSL_EmifaHandle    hEmifa,
    CSL_EmifaConfig    *config
)
{
    CSL_Status status = CSL_SOK;

    if(hEmifa == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if(config == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /* setting the Chip Enable2 Configuration register */
        hEmifa->regs->CE2CFG = config->CE2CFG;   

         /* setting the Chip Enable3 Configuration register */
        hEmifa->regs->CE3CFG = config->CE3CFG;  

         /* setting the Chip Enable4 Configuration register */
        hEmifa->regs->CE4CFG = config->CE4CFG;  

         /* setting the Chip Enable5 Configuration register */
        hEmifa->regs->CE5CFG = config->CE5CFG;  

         /* setting the Asynchronous Wait Cycle Configuration register */
        hEmifa->regs->AWCC = config->AWCC;  

        /* setting the Interrupt Raw Register */
        hEmifa->regs->INTRAW = config->INTRAW;

        /* setting Interrupt Masked Register */
        hEmifa->regs->INTMSK = config->INTMSK;

        /* setting the Interrupt Mask Set Register */
        hEmifa->regs->INTMSKSET = config->INTMSKSET;

        /* setting the Interrupt Mask Clear Register */
        hEmifa->regs->INTMSKCLR = config->INTMSKCLR;

        /* setting the Burst Priority Register */
        hEmifa->regs->BPRIO = config->BPRIO;   
    }
        
    return (status);
}

