/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *  @file    csl_emifaOpen.c
 *  
 *  @path    $(CSLPATH)\src\emifa
 *
 *  @desc    File for functional layer of CSL API @a CSL_emifaOpen()
 *           - The @a CSL_emifaOpen() function definition & it's associated 
 *             functions
 *
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  10-May-2005 RM  File Created.
 *  
 *  09-Sep-2005 NG  Updation according to coding guidelines
 *  08-Sep-2008 Update for Doxygen
 *  
 * =============================================================================
 */
#include <csl_emifa.h>


#pragma CODE_SECTION (CSL_emifaOpen, ".text:csl_section:emifa");
CSL_EmifaHandle CSL_emifaOpen (
    CSL_EmifaObj      *pEmifaObj,
    CSL_InstNum       emifaNum,
    CSL_EmifaParam    *pEmifaParam,
    CSL_Status        *pStatus
)
{    
    CSL_EmifaHandle       hEmifa = (CSL_EmifaHandle)NULL;
    CSL_EmifaBaseAddress  baseAddress;  
  
    if (pStatus == NULL) {
        /* Do nothing: Module handle already initialised to NULL */ 
    }
    else if (pEmifaObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else {
        *pStatus = CSL_emifaGetBaseAddress(emifaNum, pEmifaParam, &baseAddress);
        if (*pStatus == CSL_SOK) {
            pEmifaObj->regs = baseAddress.regs;
            pEmifaObj->perNum = (CSL_InstNum)emifaNum;
            hEmifa = (CSL_EmifaHandle)pEmifaObj;
        } 
        else {
            pEmifaObj->regs = (CSL_EmifaRegsOvly)NULL;
            pEmifaObj->perNum = (CSL_InstNum)-1;
        }
    }

    return (hEmifa);
}

