/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 * Use of this software is controlled by the terms and conditions found
 * in the license agreement under which this software has been supplied
 * provided
 * ==========================================================================
*/

/** ===========================================================================
 *  @file csl_gpioOpen.c
 *
 *  @path $(CSLPATH)\src\gpio
 * 
 *  @desc The CSL_gpioOpen() function definition & it's associated functions
 * ============================================================================
 */

/* ============================================================================
 * Revision History
 * ===============
 *  10-jun-2004 PGR File created
 *  04-Sep-2004 Nsr Updated function and documentation for CSL_gpioOpen.
 *                - Removed the include file, csl_resource.h.
 *  11-Oct-2004 Nsr renamed the local variable "st" as "status"
 *  06-Mar-2006 ds  Updated the documentation
 *  08-Sep-2008 Update for Doxygen
 * ============================================================================
 */
 
#include <csl_gpio.h>          

#pragma CODE_SECTION (CSL_gpioOpen, ".text:csl_section:gpio");
CSL_GpioHandle CSL_gpioOpen (
    CSL_GpioObj   *pGpioObj,
    CSL_InstNum   gpioNum,
    CSL_GpioParam *pGpioParam,
    CSL_Status    *pStatus
)
{
    CSL_GpioHandle hGpio = (CSL_GpioHandle)NULL;
    CSL_GpioBaseAddress baseAddress;

    if (pStatus == NULL) {
        /* do nothing : already the module is initialized to NULL */
    }
    
    else if (pGpioObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }

    else { 
        *pStatus = CSL_gpioGetBaseAddress(gpioNum, pGpioParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pGpioObj->regs = baseAddress.regs;
            pGpioObj->gpioNum = (CSL_InstNum)gpioNum;
            pGpioObj->numPins = CSL_GPIO_NUM_PINS;
            hGpio = (CSL_GpioHandle)pGpioObj;
        } 
        else {
            pGpioObj->regs = (CSL_GpioRegsOvly)NULL;
            pGpioObj->gpioNum = (CSL_InstNum)-1;
            
        }
    }
    return (hGpio);
}
