/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** 
 *  @file    csl_hpiGetHwStatus.c
 *
 *  @path    $(CSLPATH)\src\hpi
 *
 *  @brief   File for functional layer of CSL API @a CSL_hpiGetHwStatus()
 *
 */
/* =============================================================================
 *  Revision History
 *  ================
 * 06-Feb-2006 ds  Removed CSL_HPI_QUERY_PID_REV, CSL_HPI_QUERY_PID_TYPE and
 *                  CSL_HPI_QUERY_PID_CLASS
 * 10-May-2008 Removed CSL_HPI_QUERY_HRDY, CSL_HPI_QUERY_FETCH. 
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <csl_hpi.h>
#include <csl_hpiAux.h>


#pragma CODE_SECTION (CSL_hpiGetHwStatus, ".text:csl_section:hpi");
CSL_Status CSL_hpiGetHwStatus (
    CSL_HpiHandle           hHpi,
    CSL_HpiHwStatusQuery    query,
    void                    *response
)
{
    CSL_Status status = CSL_SOK;

    if (hHpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (query) {
           case CSL_HPI_QUERY_HPI_RST:
               CSL_hpiGetHpicHpiRst(hHpi,response);
               break;

           case CSL_HPI_QUERY_HWOB_STAT:
               CSL_hpiGetHpicHwobStat(hHpi,response);
               break;

           default:
                status = CSL_ESYS_INVQUERY ;    
        }
    }

    return (status);
}

