/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** 
 *  @file    csl_hpiHwControl.c
 *
 *  @path    $(CSLPATH)\src\hpi
 *
 *  @brief   File for functional layer of CSL API @a CSL_hpiHwControl()
 *
 */
/* ============================================================================
 * Revision History
 * ================
 * 06-Mar-2006 sd  Removed the invalid parameter check
 * 10-May-2008 Removed CSL_HPI_CMD_SET_DSP_INT, CSL_HPI_CMD_RESET_HINT. Added CSL_HPI_CMD_RESET_HPI
 * 09-Sept-2008 Updated for Doxygen
 * ============================================================================
 */
#include <csl_hpi.h>
#include <csl_hpiAux.h>



#pragma CODE_SECTION (CSL_hpiHwControl, ".text:csl_section:hpi");
CSL_Status CSL_hpiHwControl (
    CSL_HpiHandle          hHpi,
    CSL_HpiHwControlCmd    cmd,
    void                   *arg
)
{
    CSL_Status status = CSL_SOK;
    
    if (hHpi == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else {
        switch (cmd) {
            /* Reset the Host-to-DSP Interrupt */        
            case CSL_HPI_CMD_RESET_DSP_INT:
                CSL_hpiResetDspInt(hHpi);
                break;
            
            /* Set the HPIC Host Interrupt */        
            case CSL_HPI_CMD_SET_HINT:
                CSL_hpiSetHint(hHpi);
                break;

            /* Rest the HPIC Host Interrupt */        
            case CSL_HPI_CMD_RESET_HPI:
                CSL_hpiResetHpi(hHpi);
                break;

            default:
                status = CSL_ESYS_INVCMD;
        }
    }
    return (status);
}

