/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** 
 *  @file    csl_hpiOpen.c
 *
 *  @path    $(CSLPATH)\src\hpi
 *
 *  @brief   File for functional layer of CSL API @a CSL_hpiOpen()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */

#include <csl_hpi.h>


#pragma CODE_SECTION (CSL_hpiOpen, ".text:csl_section:hpi");
CSL_HpiHandle  CSL_hpiOpen (
    CSL_HpiObj      *pHpiObj,   
    CSL_InstNum     hpiNum,     
    CSL_HpiParam    *pHpiParam, 
    CSL_Status      *pStatus
)
{   
    CSL_HpiHandle         hHpi = (CSL_HpiHandle)NULL;
    CSL_HpiBaseAddress    baseAddress;

    if (pStatus == NULL) {
        /* do nothing : module handle is already initialized to NULL */
    }
    else if (pHpiObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else {
        *pStatus = CSL_hpiGetBaseAddress (hpiNum, pHpiParam, &baseAddress);
        if (*pStatus == CSL_SOK) {
            pHpiObj->regs = baseAddress.regs;
            pHpiObj->hpiNum = (CSL_InstNum) hpiNum;
            hHpi = (CSL_HpiHandle) pHpiObj;
        } 
        else {
            pHpiObj->regs = (CSL_HpiRegsOvly)NULL;
            pHpiObj->hpiNum = (CSL_InstNum)-1;
        }
    }
    return (hHpi);
}

