/*  ===========================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *  @file csl_i2cGetHwSetup.c
 *
 *  @brief File for functional layer of CSL API CSL_i2cGetHwSetup()
 *
 *  @path $(CSLPATH)\i2c\src
 *
 *  Description
 *    - The CSL_i2cGetHwSetup() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 28/5/2004
 *    - Reason: created the sources
 *
 *  @date 28th May, 2004
 *  @author Santosh Narayanan.
 */


/*  ============================================================================
 *  Revision History
 *  ================
 * 24-Mar-2008 Fix to copy runMode and repeatMode. Optimized copying clocksetup
 * 09-Sept-2008 Updated for Doxygen
 *  ============================================================================
 */

#include <csl_i2c.h>


#pragma CODE_SECTION (CSL_i2cGetHwSetup, ".text:csl_section:i2c")
CSL_Status CSL_i2cGetHwSetup (
    CSL_I2cHandle     hI2c,
    CSL_I2cHwSetup    *setup
)
{
    CSL_Status status = CSL_SOK;

    if (hI2c == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        setup->mode = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_MST);
        setup->dir = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_TRX);
        setup->addrMode = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_XA);
        setup->ownaddr = CSL_FEXT(hI2c->regs->ICOAR, I2C_ICOAR_OADDR);
        setup->sttbyteen = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_STB);
        setup->ackMode = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_NACKMOD);
        setup->runMode = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_FREE);
        setup->repeatMode = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_RM);
        setup->loopBackMode = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_DLB);
        setup->freeDataFormat = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_FDF);
        setup->resetMode = CSL_FEXT(hI2c->regs->ICMDR, I2C_ICMDR_IRS);
        setup->bcm = CSL_FEXT(hI2c->regs->ICEMDR, I2C_ICEMDR_BCM);
        setup->inten = hI2c->regs->ICIMR ;
    
        setup->clksetup->prescalar = CSL_FEXT(hI2c->regs->ICPSC, I2C_ICPSC_IPSC);
        setup->clksetup->clklowdiv = CSL_FEXT(hI2c->regs->ICCLKL, I2C_ICCLKL_ICCL);
        setup->clksetup->clkhighdiv = CSL_FEXT(hI2c->regs->ICCLKH, I2C_ICCLKH_ICCH);
    
    }
    return (status);
}

