/* ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *  @file csl_i2cGetHwStatus.c
 *
 *  @brief File for functional layer of CSL API CSL_i2cGetHwStatus()
 *
 *  @path  $(CSLPATH)\i2c\src
 *
 *  Description
 *    - The CSL_i2cGetHwStatus() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 28/5/2004
 *    - Reason: created the sources
 *
 *  @date 28th May, 2004
 *  @author Santosh Narayanan.
 */
/* =============================================================================
 *  Revision History
 *  ================
 * 06-Feb-2006 ds  Removed CSL_I2C_QUERY_REV, CSL_I2C_QUERY_CLASS and 
 *                  CSL_I2C_QUERY_TYPE queries
 * 23-Apr-2008 Added Query for Class, Type and Rev. 
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <csl_i2c.h>
#include <csl_i2cAux.h>


#pragma CODE_SECTION (CSL_i2cGetHwStatus, ".text:csl_section:i2c")
CSL_Status CSL_i2cGetHwStatus (
    CSL_I2cHandle           hI2c,
    CSL_I2cHwStatusQuery    query,
    void                    *response
)
{
    CSL_Status status = CSL_SOK;

    if (hI2c == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (query) {
            case CSL_I2C_QUERY_CLOCK_SETUP:
                CSL_i2cGetClockSetup(hI2c, response);
                break;

            case CSL_I2C_QUERY_BUS_BUSY:
                CSL_i2cGetBusBusy(hI2c, response);
                break;

            case CSL_I2C_QUERY_RX_RDY:
                CSL_i2cGetRxRdy(hI2c, response);
                break;

            case CSL_I2C_QUERY_TX_RDY:
                CSL_i2cGetTxRdy(hI2c, response);
                break;

            case CSL_I2C_QUERY_ACS_RDY:
                CSL_i2cGetAcsRdy(hI2c, response);
                break;

            case CSL_I2C_QUERY_SCD:
                CSL_i2cGetScd(hI2c, response);
                break;

            case CSL_I2C_QUERY_AD0:
                CSL_i2cGetAd0(hI2c, response);
                break;

            case CSL_I2C_QUERY_AAS:
                CSL_i2cGetAas(hI2c, response);
                break;

            case CSL_I2C_QUERY_RSFULL:
                CSL_i2cGetRsFull (hI2c, response);
                break;

            case CSL_I2C_QUERY_XSMT:
                CSL_i2cGetXsmt(hI2c, response);
                break;

            case CSL_I2C_QUERY_AL:
                CSL_i2cGetAl(hI2c, response);
                break;

            case CSL_I2C_QUERY_SDIR:
                CSL_i2cGetSdir(hI2c, response);
                break;

            case CSL_I2C_QUERY_NACKSNT:
                CSL_i2cGetNacksnt(hI2c, response);
                break;

            case CSL_I2C_QUERY_RDONE:
                CSL_i2cGetRdone(hI2c, response);
                break;

            case CSL_I2C_QUERY_BITCOUNT:
                CSL_i2cGetBitcount(hI2c, response);
                break;

            case CSL_I2C_QUERY_INTCODE:
                CSL_i2cGetIntcode(hI2c, response);
                break;

            case CSL_I2C_QUERY_REV:
                CSL_i2cGetRev(hI2c, response);
                break;

            case CSL_I2C_QUERY_CLASS:
                CSL_i2cGetClass(hI2c, response);
                break;

            case CSL_I2C_QUERY_TYPE:
                CSL_i2cGetType(hI2c, response);
                break;

            default:
                status = CSL_ESYS_INVQUERY ;
                break;
        }
    }
    return (status);
}

