/* ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *  @file csl_i2cHwControl.c
 *
 *  @brief File for functional layer of CSL API CSL_i2cHwControl()
 *
 *  @path  $(CSLPATH)\i2c\src
 *
 *  Description
 *    - The CSL_i2cHwControl() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 28/5/2004
 *    - Reason: created the sources
 *
 *  @date 28th May, 2004
 *    @author Santosh Narayanan.
 */
/** ============================================================================
 *  Revision History
 *  ===============
 * 31-aug-2004 Hs Updated the CSL_i2cHwControl to call respective functions.
 * 11-oct-2004 Hs updated code according to code review comments.
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <csl_i2c.h>
#include <csl_i2cAux.h>


#pragma CODE_SECTION (CSL_i2cHwControl, ".text:csl_section:i2c");
CSL_Status  CSL_i2cHwControl(
    CSL_I2cHandle          hI2c,
    CSL_I2cHwControlCmd    cmd,
    void                   *arg
)
{
    CSL_Status status = CSL_SOK;

    if (hI2c == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else {
        switch (cmd) {
            case CSL_I2C_CMD_ENABLE:
                CSL_i2cEnable(hI2c);
                break;

            case CSL_I2C_CMD_RESET:
                CSL_i2cReset(hI2c);
                break;

            case CSL_I2C_CMD_OUTOFRESET:
                CSL_i2cOutOfReset(hI2c);
                break;

            case CSL_I2C_CMD_CLEAR_STATUS:
                CSL_i2cClearStatus(hI2c, arg);
                break;

            case CSL_I2C_CMD_SET_SLAVE_ADDR:
                if (arg == NULL) {
                    status = CSL_ESYS_INVPARAMS;
                }
                else {
                    CSL_i2cSetSlaveAddr(hI2c, arg);
                }
                break;

            case CSL_I2C_CMD_SET_DATA_COUNT:
                if (arg == NULL) {
                    status = CSL_ESYS_INVPARAMS;
                }
                else {
                    CSL_i2cSetDataCount(hI2c, arg);
                }
                break;

            case CSL_I2C_CMD_START:
                CSL_i2cStart(hI2c);
                break;

            case CSL_I2C_CMD_STOP:
                CSL_i2cStop(hI2c);
                break;

            case CSL_I2C_CMD_DIR_TRANSMIT:
                CSL_i2cDirTransmit(hI2c);
                break;

            case CSL_I2C_CMD_DIR_RECEIVE:
                CSL_i2cDirReceive(hI2c);
                break;

            case CSL_I2C_CMD_RM_ENABLE:
                CSL_i2cRmEnable(hI2c);
                break;

            case CSL_I2C_CMD_RM_DISABLE:
                CSL_i2cRmDisable(hI2c);
                break;

            case CSL_I2C_CMD_DLB_ENABLE:
                CSL_i2cDlbEnable(hI2c);
                break;

            case CSL_I2C_CMD_DLB_DISABLE:
                CSL_i2cDlbDisable(hI2c);
                break;

            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }
    return (status);
}

