/* ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *  @file csl_i2cHwSetup.c
 *
 *  @brief File for functional layer of CSL API @a CSL_i2cHwSetup()
 *
 *  @path $(CSLPATH)\i2c\src
 *
 *  Description
 *    - The @a CSL_i2cHwSetup() function definition & it's associated
 *      functions
 *
 *  Modification 1
 *    - Modified on: 28/5/2004
 *    - Reason: created the sources
 *
 *  @date 28th May, 2004
 *  @author Santosh Narayanan.
 *  ============================================================================
 */

/* =============================================================================
 *  Revision History
 *  ================
 * 23-Apr-2008 Replaced hardcoded values with defines
 * 09-Sept-2008 Updated for Doxygen
 *  ============================================================================
 */

#include <csl_i2c.h>


#pragma CODE_SECTION (CSL_i2cHwSetup, ".text:csl_section:i2c");
CSL_Status CSL_i2cHwSetup (
    CSL_I2cHandle     hI2c,
    CSL_I2cHwSetup    *setup
)
{
    CSL_Status	status = CSL_SOK;
	Uint32		tmpReg;

    if (hI2c == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /*  Set the mode(Master/Slave), direction(Transmitter/Receiver),
         *  addressing mode(7-bit or 10-bit, free run mode, free data 
         *  format and start byte mode.
         */
        tmpReg = hI2c->regs->ICMDR;
        CSL_FINS(tmpReg, I2C_ICMDR_MST, setup->mode);
        CSL_FINS(tmpReg, I2C_ICMDR_NACKMOD, setup->ackMode);
        CSL_FINS(tmpReg, I2C_ICMDR_TRX, setup->dir);
        CSL_FINS(tmpReg, I2C_ICMDR_XA, setup->addrMode);
        CSL_FINS(tmpReg, I2C_ICMDR_FREE, setup->runMode);
        CSL_FINS(tmpReg, I2C_ICMDR_STB, setup->sttbyteen);
        CSL_FINS(tmpReg, I2C_ICMDR_FDF, setup->freeDataFormat);
        CSL_FINS(tmpReg, I2C_ICMDR_RM, setup->repeatMode);
        CSL_FINS(tmpReg, I2C_ICMDR_DLB, setup->loopBackMode);
        CSL_FINS(tmpReg, I2C_ICMDR_IRS, setup->resetMode);
        hI2c->regs->ICMDR = tmpReg;

        /* set Backward Compatibility Mode  */
        hI2c->regs->ICEMDR = (hI2c->regs->ICEMDR & CSL_I2C_ICEMDR_BCM_MASK)
                               | (CSL_FMK(I2C_ICEMDR_BCM, setup->bcm));

        /* Set the own address of the given instance        */
        CSL_FINS(hI2c->regs->ICOAR, I2C_ICOAR_OADDR, setup->ownaddr);

        /* The interrupt status is set into the interrupt enable register  */
        hI2c->regs->ICIMR = setup->inten ;

        /* Set up the prescalar value       */
        CSL_FINS(hI2c->regs->ICPSC, I2C_ICPSC_IPSC, setup->clksetup->prescalar);

        /* Set the clock low value         */
        CSL_FINS(hI2c->regs->ICCLKL, I2C_ICCLKL_ICCL, 
                 setup->clksetup->clklowdiv);

        /* Set the clock high value      */
        CSL_FINS(hI2c->regs->ICCLKH, I2C_ICCLKH_ICCH, 
                 setup->clksetup->clkhighdiv);
    }
    return (status);
}

