/* ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *  @file csl_i2cOpen.c
 *
 *  @brief File for functional layer of CSL API @a CSL_i2cOpen()
 *
 *  @path $(CSLPATH)\i2c\src
 *
 *  Description
 *    - The @a CSL_i2cOpen() function definition & it's associated functions

 *  Modification 1
 *    - Created on: 28/05/2004
 *
 *  @date 28th May, 2004
 *  @author Santosh Narayanan.
 */
/* =============================================================================
 *  Revision History
 *  ===============
 * 31-aug-2004 Hs Updated function and documentation for CSL_i2cOpen.
 *                 - Removed the include file, csl_resource.h.
 * 11-oct-2004 Hs updated code according to code review comments.
 * 15-nov-2005 Hs Removed the assignment of pI2cParam and 
 				   redundant pStatus check
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <csl_i2c.h>


#pragma CODE_SECTION (CSL_i2cOpen, ".text:csl_section:i2c");
CSL_I2cHandle CSL_i2cOpen (
    CSL_I2cObj      *pI2cObj,
    CSL_InstNum      i2cNum,
    CSL_I2cParam    *pI2cParam,
    CSL_Status      *pStatus
)
{
    CSL_I2cHandle      hI2c = (CSL_I2cHandle)NULL;
    CSL_I2cBaseAddress baseAddress;

    /* Added according to review comment 1. */
    if (pStatus == NULL) {
        /* do nothing : module handle is already initialized to NULL */
    }
    else if (pI2cObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else {
        *pStatus = CSL_i2cGetBaseAddress(i2cNum, pI2cParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pI2cObj->regs = baseAddress.regs;
            pI2cObj->perNum = (CSL_InstNum)i2cNum;
            hI2c = (CSL_I2cHandle)pI2cObj;
        }
        else {
            pI2cObj->regs = (CSL_I2cRegsOvly)NULL;
            pI2cObj->perNum = (CSL_InstNum)-1;
        }
    }
    return (hI2c);
}

