/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/*  ============================================================================
 *   @file  _csl_mcbspBlockAssign.c
 *
 *   @path  $(CSLPATH)\src\mcbsp
 *
 *   @desc  File for functional layer of CSL API _CSL_mcbspBlockAssign()
 *
 */

/* =============================================================================
 * Revision History
 * ================
 *  June 29,2004 Pratheesh Gangadhar - Created
 *
 * =============================================================================
 */

#include <csl_mcbsp.h>
#include <_csl_mcbsp.h>


#pragma CODE_SECTION (_CSL_mcbspBlockAssign, ".text:csl_section:mcbsp");
CSL_Status  _CSL_mcbspBlockAssign (
    CSL_McbspHandle         hMcbsp,
    CSL_McbspPartition      partition,
    CSL_McbspBlock          block
)
{
    CSL_Status  status = CSL_SOK;

    if (partition & 0x01) {
        if ((CSL_FEXT(hMcbsp->regs->MCR, MCBSP_MCR_RMCME) == 0)
            && (CSL_FEXT(hMcbsp->regs->MCR, MCBSP_MCR_RMCM) == 1)) {
            if ((block & 0x01) && partition == 3) {
               /* Odd blocks can be assinged to only partition B */
               CSL_FINS( hMcbsp->regs->MCR, MCBSP_MCR_RPBBLK, block );
            }
            else {
                if ((!(block & 0x01)) && partition == 1) {
                   /* Even blocks can be assinged to only partition A */
                   CSL_FINS( hMcbsp->regs->MCR, MCBSP_MCR_RPABLK, block );
                }
                else
                    status = CSL_EMCBSP_INVPARAMS;
           }
        }
        else
            status = CSL_EMCBSP_INVMODE;
    }
    else {
        if ((CSL_FEXT(hMcbsp->regs->MCR, MCBSP_MCR_XMCME) == 0)
            && (CSL_FEXT(hMcbsp->regs->MCR, MCBSP_MCR_XMCM) != 0)) {
            if ((block & 0x01) && partition == 2) {
                /* Odd blocks can be assinged to only partition B */
                CSL_FINS( hMcbsp->regs->MCR, MCBSP_MCR_XPBBLK, block );
            }
            else {
                if ((!(block & 0x01)) && partition == 0) {
                    /* Even blocks can be assinged to only partition A */
                    CSL_FINS( hMcbsp->regs->MCR, MCBSP_MCR_XPABLK, block );
                 }
                 else
                     status = CSL_EMCBSP_INVPARAMS;
            }
        }
        else
            status = CSL_EMCBSP_INVMODE;
    }

    return (status);

}


