/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  csl_mcbspGetHwStatus.c
 *
 *   @path  $(CSLPATH)\src\mcbsp
 *
 *   @desc  File for functional layer of CSL API CSL_mcbspGetHwStatus()
 *
 */

/* =============================================================================
 * Revision History
 * ================
 *  June 29,2004  Pratheesh Gangadhar - Created
 *  Oct  27, 2005 ds  - Removed CSL_MCBSP_QUERY_PID query
 *  Feb 02, 2006  ds  - Removed CSL_MCBSP_QUERY_TX_INT_MODE and
 *                      CSL_MCBSP_QUERY_TX_INT_MODE queries
 * =============================================================================
 */
#include <csl_mcbsp.h>
#include <_csl_mcbsp.h>
#include <csl_mcbspAux.h>


#pragma CODE_SECTION (CSL_mcbspGetHwStatus, ".text:csl_section:mcbsp");
CSL_Status  CSL_mcbspGetHwStatus (
    CSL_McbspHandle                hMcbsp,
    CSL_McbspHwStatusQuery         myQuery,
    void                           *response
)
{
    CSL_Status status = CSL_SOK;

    if (hMcbsp == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if(response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch(myQuery) {
            case CSL_MCBSP_QUERY_CUR_RX_BLK:
                  CSL_mcbspGetCurRxBlk (hMcbsp, response);
                  break;

            case CSL_MCBSP_QUERY_CUR_TX_BLK:
                  CSL_mcbspGetCurTxBlk (hMcbsp, (CSL_BitMask16 *)response);
                  break;

            case CSL_MCBSP_QUERY_DEV_STATUS:
                  CSL_mcbspGetDevStatus (hMcbsp, (CSL_BitMask16 *)response);
                  break;

            case CSL_MCBSP_QUERY_TX_RST_STAT:
                  CSL_mcbspGetTxRstStat (hMcbsp, response);
                  break;

            case CSL_MCBSP_QUERY_RX_RST_STAT:
                 CSL_mcbspGetRxRstStat (hMcbsp, response);
                 break;

            default:
                status = CSL_ESYS_INVQUERY;
                break;
        }
    }

    return(status);
}

