/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  csl_mcbspHwSetupRaw.c
 *
 *   @path  $(CSLPATH)\src\mcbsp
 *
 *   @desc  File for functional layer of CSL API CSL_mcbspHwSetupRaw()
 *
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  15-Feb-2005 NSR File Created.
 *
 *  04-Jul-2005 ds            - Register naming convention used for
 *                              multichannel registers are changed according
 *                              the changes in cslr_mcbsp.h
 *  21-Sep-2005 ds            - Removed the DXR and DRR register from config
 *                              data structure
 * =============================================================================
 */

#include <csl_mcbsp.h>


#pragma CODE_SECTION (CSL_mcbspHwSetupRaw, ".text:csl_section:mcbsp");
CSL_Status  CSL_mcbspHwSetupRaw (
    CSL_McbspHandle     hMcbsp,
    CSL_McbspConfig     *config
)
{
    CSL_Status status = CSL_SOK;

    if (hMcbsp == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (config == NULL ) {
        status = CSL_ESYS_INVPARAMS;
    }
    else{
        hMcbsp->regs->SPCR     = config->SPCR;
        hMcbsp->regs->RCR      = config->RCR ;
        hMcbsp->regs->XCR      = config->XCR ;
        hMcbsp->regs->SRGR     = config->SRGR;
        hMcbsp->regs->MCR      = config->MCR ;
        hMcbsp->regs->RCERE0   = config->RCERE0;
        hMcbsp->regs->XCERE0   = config->XCERE0;
        hMcbsp->regs->PCR      = config->PCR  ;
        hMcbsp->regs->RCERE1   = config->RCERE1;
        hMcbsp->regs->XCERE1   = config->XCERE1;
        hMcbsp->regs->RCERE2   = config->RCERE2;
        hMcbsp->regs->XCERE2   = config->XCERE2;
        hMcbsp->regs->RCERE3   = config->RCERE3;
        hMcbsp->regs->XCERE3   = config->XCERE3;
    }

    return status;
}
