/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  csl_mcbspOpen.c
 *
 *   @path  $(CSLPATH)\src\mcbsp
 *
 *   @desc  File for functional layer of CSL API CSL_mcbspOpen()
 *
 */

/* =============================================================================
 *  Revision History
 *  ================
 *  15-Feb-2005 NSR      - Updated function and documentation for CSL_mcbspOpen.
 *                       - Removed the include file, csl_resource.h.
 *  15-Nov-2005 ds       - Removed *pMcbspParam = *pMcbspParam
 *
 * =============================================================================
 */

#include <csl_mcbsp.h>


#pragma CODE_SECTION (CSL_mcbspOpen, ".text:csl_section:mcbsp");
CSL_McbspHandle  CSL_mcbspOpen (
    CSL_McbspObj        *pMcbspObj,
    CSL_InstNum         mcbspNum,
    CSL_McbspParam      *pMcbspParam,
    CSL_Status          *pStatus
)
{
    CSL_Status              status;
    CSL_McbspHandle         hMcbsp = NULL;
    CSL_McbspBaseAddress    baseAddress;

    if (pStatus == NULL) {
        /* do nothing */
    }
    else if (pMcbspObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else{
        status = CSL_mcbspGetBaseAddress(mcbspNum, pMcbspParam, &baseAddress);

        if (status == CSL_SOK) {
            pMcbspObj->regs = baseAddress.regs;
            pMcbspObj->perNum = (CSL_InstNum)mcbspNum;
            hMcbsp = (CSL_McbspHandle)pMcbspObj;
        }
        else {
            pMcbspObj->regs = (CSL_McbspRegsOvly)NULL;
            pMcbspObj->perNum = (CSL_InstNum)-1;
            hMcbsp = (CSL_McbspHandle)NULL;
        }

        *pStatus = status;
    }

    return hMcbsp;
}


