/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */

/** ============================================================================
 *   @file  csl_mcbspRead.c
 *
 *   @path  $(CSLPATH)\src\mcbsp
 *
 *   @desc  File for functional layer of CSL API CSL_mcbspRead()
 *
 */

/* =============================================================================
 * Revision History
 * ================
 *  Jun 29, 2004 Pratheesh Gangadhar - Created
 *  Mar 23, 2006 ds Added check for invalid handle
 * =============================================================================
 */

#include <csl_mcbsp.h>


#pragma CODE_SECTION (CSL_mcbspRead, ".text:csl_section:mcbsp");
CSL_Status  CSL_mcbspRead (
    CSL_McbspHandle     hMcbsp,
    CSL_McbspWordLen    wordLen,
    void                *data
)
{
    CSL_Status status = CSL_SOK;

    if (hMcbsp == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (data == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }else {
        switch(wordLen) {
            case CSL_MCBSP_WORDLEN_8:
            case CSL_MCBSP_WORDLEN_12:
            case CSL_MCBSP_WORDLEN_16: {
                *((Uint16 *)data) = (Uint16)hMcbsp->regs->DRR;
                break;
            }
            case CSL_MCBSP_WORDLEN_20:
            case CSL_MCBSP_WORDLEN_24:
            case CSL_MCBSP_WORDLEN_32: {
                *((Uint32 *)data) = (Uint32)hMcbsp->regs->DRR;
                break;
            }
            default:
                status = CSL_EMCBSP_INVSIZE;
        }
    }
    return(status);
}
