/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005                 
 *                                                                              
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.             
 * ============================================================================
 */
  
/** ============================================================================
 *   @file  csl_memprotGetHwStatus.c
 *
 *   @path  $(CSLPATH)\src\memprot
 *
 *   @desc  File for functional layer of CSL API CSL_memprotGetHwStatus ()
 *
 */

/* =============================================================================
 * Revision History
 * ===============
 * 16-Jul-2004  Ruchika Kharwar File Created
 * 16-Nov-2005  ds  Updated the documentation
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */

#include <csl_memprot.h>
#include <csl_memprotAux.h>

#pragma CODE_SECTION (CSL_memprotGetHwStatus, ".text:csl_section:memprot") 
CSL_Status CSL_memprotGetHwStatus (
    CSL_MemprotHandle         hMemprot,
    CSL_MemprotHwStatusQuery  query,
    void                      *response
)
{
    CSL_Status status = CSL_SOK;
    
    if (hMemprot == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }

    else {
        switch (query) {
            case CSL_MEMPROT_QUERY_FAULT:
                CSL_memprotGetFaultStatus(hMemprot,
                                      (CSL_MemprotFaultStatus *)response);
                break;

            case CSL_MEMPROT_QUERY_PAGEATTR:
                ((CSL_MemprotPageAttr *)response)->attr = 
                              CSL_memprotGetPageAttr(hMemprot, 
                                    ((CSL_MemprotPageAttr*)response)->page);
                break;

            case CSL_MEMPROT_QUERY_LOCKSTAT:
                *((CSL_MemprotLockStatus *)response) = 
                                            CSL_memprotGetLockStat(hMemprot);
                break;

            default:
                status = CSL_ESYS_INVQUERY ;
        }
    }
    return status;
}
