/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005                 
 *                                                                              
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.             
 * ============================================================================
 */ 

/** ============================================================================
 *   @file  csl_memprotHwControl.c
 *
 *   @path  $(CSLPATH)\src\memprot
 *
 *   @desc  File for functional layer of CSL API CSL_memprotHwControl ()
 *
 */
 
/* =============================================================================
 * Revision History
 * ===============
 * 16-Jul-2004  Ruchika Kharwar File Created
 * 16-Nov-2005 ds   Updated the documentation
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
 
#include <csl_memprot.h>
#include <csl_memprotAux.h>


#pragma CODE_SECTION (CSL_memprotHwControl, ".text:csl_section:memprot");
CSL_Status CSL_memprotHwControl (
    CSL_MemprotHandle        hMemprot,
    CSL_MemprotHwControlCmd  cmd,
    void                     *arg
)
{
    CSL_Status status = CSL_SOK;
    
    if (hMemprot == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    
    else if ((arg == NULL) && ((cmd >= 0) && \
                    (cmd <= CSL_MEMPROT_CMD_PAGEATTR))){
        status = CSL_ESYS_INVPARAMS;
    }
    
    else {
        switch (cmd) {
            case CSL_MEMPROT_CMD_LOCK:
                status = CSL_memprotLock(hMemprot, (Uint32 *)(arg));
                break;

            case CSL_MEMPROT_CMD_UNLOCK:
                status = CSL_memprotUnLock(hMemprot, (Uint32 *)(arg));
                break;

            case CSL_MEMPROT_CMD_PAGEATTR:
                CSL_memprotSetPageAttr(hMemprot,
                                   ((CSL_MemprotPageAttr *)arg)->page,
                                   ((CSL_MemprotPageAttr *)arg)->attr);
                break;

            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }   
    return status;
}
