/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005                 
 *                                                                             
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.             
 * ============================================================================
 */ 

/** ============================================================================
 *   @file  csl_memprotHwSetup.c
 *
 *   @path  $(CSLPATH)\src\memprot
 *
 *   @desc  File for functional layer of CSL API CSL_memprotHwSetup ()
 *
 */

/* =============================================================================
 * Revision History
 * ===============
 * 16-Jul-2004  Ruchika Kharwar File Created
 * 16-Nov-2005  ds  Updated the documentation
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */

#include <csl_memprot.h>
#include <csl_memprotAux.h>


#pragma CODE_SECTION (CSL_memprotHwSetup, ".text:csl_section:memprot");
CSL_Status CSL_memprotHwSetup (
    /* Handle to the memprot instance */
    CSL_MemprotHandle  hMemprot,
    
    /* Pointer to setup structure which contains the
     * information to program the memory protection module to a useful state.
     */
    CSL_MemprotHwSetup *setup
)
{
    CSL_Status status = CSL_SOK;
    Uint16 i;

    if (hMemprot == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }                
    else if (setup == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /* Unlock the module. This call anyways checks if the module
           is already locked/not */
        if (setup->key != NULL) {
            CSL_memprotUnLock(hMemprot,setup->key);
        }                           
        /* Program memory page attribute registers */ 
        for (i = 0;i  < setup->numPages ;i++) {
            hMemprot->regs->MPPA[i] = setup->memPageAttr[i];
        }            
        /* Lock Module */
        if (setup->key != NULL) {
            status = CSL_memprotLock(hMemprot,setup->key);
        }
    }
    return status;
}

