/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005                 
 *                                                                              
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.             
 * ============================================================================
 */ 

/** ============================================================================
 *   @file  csl_memprotOpen.c
 *
 *   @path  $(CSLPATH)\src\memprot
 *
 *   @desc  File for functional layer of CSL API CSL_memprotOpen ()
 *
 */

/* =============================================================================
 * Revision History
 * ===============
 * 16-Nov-2005 ds  updated the documentation
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
 
#include <csl_memprot.h>

#pragma CODE_SECTION (CSL_memprotOpen, ".text:csl_section:memprot");
CSL_MemprotHandle CSL_memprotOpen (
    CSL_MemprotObj   *pMemprotObj,   
    CSL_InstNum      memprotNum,     
    CSL_MemprotParam *pMemprotParam, 
    CSL_Status       *pStatus
)
{
    CSL_MemprotHandle       hMemprot = (CSL_MemprotHandle)NULL;
    CSL_MemprotBaseAddress  baseAddress;
    
    if (pStatus == NULL) {
        /* do nothing : already the module is initialized to NULL */        
    }
    
    else if (pMemprotObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }

    else {
        *pStatus = CSL_memprotGetBaseAddress(memprotNum, pMemprotParam, &baseAddress); 

        if (*pStatus == CSL_SOK) {
            pMemprotObj->regs = baseAddress.regs;
            pMemprotObj->modNum = (CSL_InstNum)memprotNum;
            hMemprot = (CSL_MemprotHandle)pMemprotObj;
        } 
        else {
            pMemprotObj->regs = (CSL_MemprotRegsOvly)NULL;
            pMemprotObj->modNum = (CSL_InstNum)-1;
        }
    }
    return (hMemprot);
}

