/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** @file csl_pllcGetHwSetup.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcGetHwSetup()
 *
 *  Path: \(CSLPATH)\src\pllc
 */

/*  ============================================================================
 *  Revision History
 *  ================
 *  20-Mar-2008 Added PLLC for new soc
 * 09-Sept-2008 Updated for Doxygen
 *  ============================================================================
 */


#include <csl_pllc.h>


#pragma CODE_SECTION (CSL_pllcGetHwSetup, ".text:csl_section:pllc");
CSL_Status CSL_pllcGetHwSetup (
    CSL_PllcHandle               hPllc,
    CSL_PllcHwSetup             *hwSetup
)
{
    CSL_Status       status   = CSL_SOK;
    CSL_PllcRegsOvly pllcRegs;

    if (hPllc == NULL )
        status = CSL_ESYS_BADHANDLE;
    else if (hwSetup == NULL)
        status = CSL_ESYS_INVPARAMS;
    else 
	{
	      pllcRegs = hPllc->regs;
        hwSetup->divEnable = 0;
    
        hwSetup->pllMode = (CSL_FEXT( pllcRegs->PLLCTL, PLLC_PLLCTL_PLLEN)) ||
								(CSL_FEXT( pllcRegs->PLLCTL, PLLC_PLLCTL_PLLRST)) ||
    							(CSL_FEXT( pllcRegs->PLLCTL, PLLC_PLLCTL_PLLPWRDN));
    
		if (CSL_FEXT (pllcRegs->POSTDIV, PLLC_POSTDIV_POSTDEN)) 
		{
    		hwSetup->divEnable |= CSL_PLLC_DIVEN_POSTDIV;
    	    hwSetup->postDiv = CSL_FEXT (pllcRegs->POSTDIV, PLLC_POSTDIV_RATIO) + 1;
    	}
    
    	hwSetup->pllM = CSL_FEXT (pllcRegs->PLLM, PLLC_PLLM_PLLM) + 1;
    
        if (CSL_FEXT (pllcRegs->PLLDIV3, PLLC_PLLDIV3_D3EN)) 
		{
			hwSetup->divEnable |= CSL_PLLC_DIVEN_PLLDIV3;
            hwSetup->pllDiv3 = CSL_FEXT (pllcRegs->PLLDIV3, PLLC_PLLDIV3_RATIO) + 1;
        }
        if (CSL_FEXT (pllcRegs->PLLDIV6, PLLC_PLLDIV6_D6EN)) 
		{
			hwSetup->divEnable |= CSL_PLLC_DIVEN_PLLDIV6;
            hwSetup->pllDiv6 = CSL_FEXT (pllcRegs->PLLDIV6, PLLC_PLLDIV6_RATIO) + 1;
		}
		if (CSL_FEXT (pllcRegs->PLLDIV7, PLLC_PLLDIV7_D7EN)) 
		{
			hwSetup->divEnable |= CSL_PLLC_DIVEN_PLLDIV7;
            hwSetup->pllDiv7 = CSL_FEXT (pllcRegs->PLLDIV7, PLLC_PLLDIV7_RATIO) + 1;
		}
		if (CSL_FEXT (pllcRegs->PLLDIV8, PLLC_PLLDIV8_D8EN)) 
		{
			hwSetup->divEnable |= CSL_PLLC_DIVEN_PLLDIV8;
            hwSetup->pllDiv8 = CSL_FEXT (pllcRegs->PLLDIV8, PLLC_PLLDIV8_RATIO) + 1;
		}
    }

    return status;
}

