/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** @file csl_pllcGetHwStatus.c
 *
 *  @brief   File for functional layer of CSL API @a CSL_pllcGetHwStatus()
 *
 *  Path: \(CSLPATH)\src\pllc
 */

/*  ============================================================================
 *  Revision History
 *  ================
 *  20-Mar-2008 Added PLLC for new soc
 * 09-Sept-2008 Updated for Doxygen
 *  ============================================================================
 */


#include <csl_pllc.h>
#include <csl_pllcAux.h>


#pragma CODE_SECTION (CSL_pllcGetHwStatus, ".text:csl_section:pllc");
CSL_Status CSL_pllcGetHwStatus (
    CSL_PllcHandle                hPllc,
    CSL_PllcHwStatusQuery         query,
    void                         *response
)
{
    CSL_Status status = CSL_SOK;

    if (hPllc == NULL)
        status = CSL_ESYS_BADHANDLE;
    else if (response == NULL)
        status = CSL_ESYS_INVPARAMS;
    else 
	{
        switch (query) 
		{
            /* Query for GOSTAT bit in PLLSTAT register*/
            case CSL_PLLC_QUERY_STATUS:
                *(CSL_BitMask32*) response = CSL_pllcGetStatus (hPllc);
                break;
            /* Query for SYSnOn bits SYSSTAT register*/
            case CSL_PLLC_QUERY_SYSCLKSTAT:
                *(CSL_BitMask32*) response = CSL_pllcGetSysClkStatus (hPllc);
                break;
            /* Query for status of RSTYPE register*/
            case CSL_PLLC_QUERY_RESETSTAT:
    			if (hPllc->pllcNum == CSL_PLLC_1) 
    	            *(CSL_BitMask32*) response = CSL_pllcGetResetStatus (hPllc);
    			else
    				status = CSL_ESYS_INVPARAMS;
                break;
            default:
               status = CSL_ESYS_INVQUERY;
               break;
        }
    }

    return status;
}

