/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** @file csl_pllcHwControl.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcHwControl()
 *
 *  Path: \(CSLPATH)\src\pllc
 */

/*  ============================================================================
 *  Revision History
 *  ================
 *  20-Mar-2008 Added PLLC for new soc
 * 09-Sept-2008 Updated for Doxygen
 *  ============================================================================
 */

#include <csl_pllc.h>
#include <csl_pllcAux.h>


#pragma CODE_SECTION (CSL_pllcHwControl, ".text:csl_section:pllc");
CSL_Status CSL_pllcHwControl (
    CSL_PllcHandle              hPllc,
    CSL_PllcHwControlCmd        cmd,
    void                       *arg
)
{
    CSL_Status status = CSL_SOK;

    if (hPllc == NULL)
        status = CSL_ESYS_BADHANDLE;
    else if ((arg == NULL) || (hPllc->pllcNum != CSL_PLLC_1))
        status = CSL_ESYS_INVPARAMS;
   	 else 
	 {
        switch (cmd) 
		{
            /* cmd to change PLLCTL and PLLCMD register of PLL controller */
            case CSL_PLLC_CMD_PLLCONTROL:
                CSL_pllcCommandCtrl (hPllc, *(CSL_BitMask32*)arg, &status);
                break;
            /* cmd to change PLLM register of PLL controller */
            case CSL_PLLC_CMD_SET_PLLM:
                CSL_pllcMultiplierCtrl (hPllc, *(Uint32*)arg, &status);
                break;
            /* cmd to change PLLDIVn_RATIO of PLLDIVn register */
            case CSL_PLLC_CMD_SET_PLLRATIO:
                CSL_pllcSetPLLDivRatio (hPllc, *(CSL_PllcDivRatio*) arg, &status);
                break;
            /* cmd to change PLLDIVn_DnEN of PLLDIVn register */
            case CSL_PLLC_CMD_PLLDIV_CONTROL:
                CSL_pllcPLLDivCtrl (hPllc, *(CSL_PllcDivideControl*) arg, &status);
                break;
			/* cmd to change postdivider register */
            case CSL_PLLC_CMD_SET_POSTDIV:
                CSL_pllcSetPostDivider(hPllc, *(Uint8 *)arg);
                break;

            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }

    return status;
}

