/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** @file csl_pllcHwSetup.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcHwSetup()
 *
 *  Path: \(CSLPATH)\src\pllc
 */

/*  ============================================================================
 *  Revision History
 *  ================
 *  20-Mar-2008 Added PLLC for new soc
 * 09-Sept-2008 Updated for Doxygen
 *  ============================================================================
 */

#include <csl_pllc.h>


#pragma CODE_SECTION (CSL_pllcHwSetup, ".text:csl_section:pllc");
CSL_Status CSL_pllcHwSetup (
    CSL_PllcHandle            hPllc,
    CSL_PllcHwSetup          *hwSetup
)
{
    CSL_PllcRegsOvly		pllcRegs;
    CSL_Status				status = CSL_SOK;
    volatile unsigned int	loopCount;

    if (hPllc == NULL)
        status = CSL_ESYS_BADHANDLE;
    else if ((hwSetup == NULL) || (hPllc->pllcNum != CSL_PLLC_1))
        status = CSL_ESYS_INVPARAMS;
    else 
	{
	  pllcRegs = hPllc->regs;
 
 		/* Ensure that PLLENSRC is cleared */
        CSL_FINS (pllcRegs->PLLCTL, PLLC_PLLCTL_PLLENSRC,
                      CSL_PLLC_PLLCTL_PLLENSRC_YES);
                             
		/* Ensure that PLLCTL is not in the PLL Mode */
        CSL_FINS (pllcRegs->PLLCTL, PLLC_PLLCTL_PLLEN,
                      CSL_PLLC_PLLCTL_PLLEN_BYPASS);
        
		/* Put PLL in reset */
            CSL_FINS (pllcRegs->PLLCTL, PLLC_PLLCTL_PLLRST,
                      CSL_PLLC_PLLCTL_PLLRST_YES);
        
		/* Ensure that PLL is not in the Power-Down state */
        CSL_FINS (pllcRegs->PLLCTL, PLLC_PLLCTL_PLLPWRDN,
                      CSL_PLLC_PLLCTL_PLLPWRDN_NO);
        
		/* Enable/Disable predivider */
        if (hwSetup->divEnable & CSL_PLLC_DIVEN_POSTDIV) 
		{
			CSL_FINS (pllcRegs->POSTDIV, PLLC_POSTDIV_POSTDEN,
                          CSL_PLLC_POSTDIV_POSTDEN_ENABLE);
            CSL_FINS (pllcRegs->POSTDIV, PLLC_POSTDIV_RATIO, hwSetup->postDiv - 1);
        }
		else 
			CSL_FINS (pllcRegs->POSTDIV, PLLC_POSTDIV_POSTDEN,
                          CSL_PLLC_POSTDIV_POSTDEN_DISABLE);
                    
		CSL_FINS (pllcRegs->PLLM, PLLC_PLLM_PLLM, hwSetup->pllM - 1);
        
		/* Enable/Disable divider 3 */
        if (hwSetup->divEnable & CSL_PLLC_DIVEN_PLLDIV3) 
		{
			CSL_FINS (pllcRegs->PLLDIV3, PLLC_PLLDIV3_D3EN,
                          CSL_PLLC_PLLDIV3_D3EN_ENABLE);
            CSL_FINS (pllcRegs->PLLDIV3, PLLC_PLLDIV3_RATIO, hwSetup->pllDiv3 - 1);
        }
		else 
			CSL_FINS (pllcRegs->PLLDIV3, PLLC_PLLDIV3_D3EN,
                          CSL_PLLC_PLLDIV3_D3EN_DISABLE);
            
        /* Enable/Disable divider 6 */
        if (hwSetup->divEnable & CSL_PLLC_DIVEN_PLLDIV6) 
		{
			CSL_FINS (pllcRegs->PLLDIV6, PLLC_PLLDIV6_D6EN,
                          CSL_PLLC_PLLDIV6_D6EN_ENABLE);
            CSL_FINS (pllcRegs->PLLDIV6, PLLC_PLLDIV6_RATIO, hwSetup->pllDiv6 - 1);
        }
		else 
			CSL_FINS (pllcRegs->PLLDIV6, PLLC_PLLDIV6_D6EN,
                          CSL_PLLC_PLLDIV6_D6EN_DISABLE);

        /* Enable/Disable divider 7 */
        if (hwSetup->divEnable & CSL_PLLC_DIVEN_PLLDIV7) 
		{
			CSL_FINS (pllcRegs->PLLDIV7, PLLC_PLLDIV7_D7EN,
                          CSL_PLLC_PLLDIV7_D7EN_ENABLE);
            CSL_FINS (pllcRegs->PLLDIV7, PLLC_PLLDIV7_RATIO, hwSetup->pllDiv7 - 1);
        }
		else 
			CSL_FINS (pllcRegs->PLLDIV7, PLLC_PLLDIV7_D7EN,
                          CSL_PLLC_PLLDIV7_D7EN_DISABLE);

        /* Enable/Disable divider 8 */
        if (hwSetup->divEnable & CSL_PLLC_DIVEN_PLLDIV8) 
		{
			CSL_FINS (pllcRegs->PLLDIV8, PLLC_PLLDIV8_D8EN,
                          CSL_PLLC_PLLDIV8_D8EN_ENABLE);
            CSL_FINS (pllcRegs->PLLDIV8, PLLC_PLLDIV8_RATIO, hwSetup->pllDiv8 - 1);
        }
		else 
			CSL_FINS (pllcRegs->PLLDIV8, PLLC_PLLDIV8_D8EN,
                          CSL_PLLC_PLLDIV8_D8EN_DISABLE);
            
        /* Set GOSET bit to change/set the dividers */
        CSL_FINS (pllcRegs->PLLCMD, PLLC_PLLCMD_GOSET, CSL_PLLC_PLLCMD_GOSET_SET);
    
        while (CSL_FEXT (pllcRegs->PLLSTAT, PLLC_PLLSTAT_GOSTAT)) 
		{
            /* Poll for divide-ratio change and clock alignment to complete */
        }
    
        
		CSL_FINS (pllcRegs->PLLCTL, PLLC_PLLCTL_PLLRST, CSL_PLLC_PLLCTL_PLLRST_NO);
        
        /* Wait for 4 cycles of the slowest of the  CLKIN/OSCIN
         * Introducing some arbitrary delay.
         */
        
		loopCount = CSL_PLLC_DELAY_2000;
        while (loopCount--)
			asm("   NOP");
                    
		CSL_FINS (pllcRegs->PLLCTL, PLLC_PLLCTL_PLLEN, hwSetup->pllMode);
   }

    return status;
}
