/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** @file  csl_pllcHwSetupRaw.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcHwSetupRaw()
 *
 *  Path: \(CSLPATH)\src\pllc
 *
 */

/*  ============================================================================
 *  Revision History
 *  ================
 *  20-Mar-2008 Added PLLC for new soc
 * 09-Sept-2008 Updated for Doxygen
 *  ============================================================================
 */

#include <csl_pllc.h>


#pragma CODE_SECTION (CSL_pllcHwSetupRaw, ".text:csl_section:pllc");
CSL_Status CSL_pllcHwSetupRaw (
    CSL_PllcHandle               hPllc,
    CSL_PllcConfig              *config
)
{
    CSL_Status      status = CSL_SOK;
    volatile Uint32 loopCount;

    if (hPllc == NULL)
        status = CSL_ESYS_BADHANDLE;
    else if ((config == NULL) || (hPllc->pllcNum != CSL_PLLC_1))
        status = CSL_ESYS_INVPARAMS;
    else 
	{
        loopCount = 65000;
   
		/* Ensure that PLLCTL is not in the PLL Mode */
        CSL_FINS (hPllc->regs->PLLCTL, PLLC_PLLCTL_PLLEN,
                      CSL_PLLC_PLLCTL_PLLEN_BYPASS);
        
		/* Put PLL in reset */
        CSL_FINS (hPllc->regs->PLLCTL, PLLC_PLLCTL_PLLRST,
                      CSL_PLLC_PLLCTL_PLLRST_YES);
        
        /* Ensure that PLLCTL is not in the Power-Down state */
        CSL_FINS (hPllc->regs->PLLCTL, PLLC_PLLCTL_PLLPWRDN,
                      CSL_PLLC_PLLCTL_PLLPWRDN_NO);
        
        /* PLL Multiplier Control register */
        hPllc->regs->PLLM   = config->PLLM;
        
        /* PLL Pre-Divider Control register */
        hPllc->regs->POSTDIV   = config->POSTDIV;
        
        /* PLL Controller Divider 3 register */
        hPllc->regs->PLLDIV3   = config->PLLDIV3;
        
        /* PLL Controller Divider 6 register */
        hPllc->regs->PLLDIV6   = config->PLLDIV6;
			
		/* PLL Controller Divider 7 register */
        hPllc->regs->PLLDIV7   = config->PLLDIV7;
			
		/* PLL Controller Divider 8 register */
        hPllc->regs->PLLDIV8   = config->PLLDIV8;
            
		/* Set GOSET bit to change/set the dividers */
        CSL_FINS (hPllc->regs->PLLCMD, PLLC_PLLCMD_GOSET,
                  CSL_PLLC_PLLCMD_GOSET_SET);
    
        while (CSL_FEXT (hPllc->regs->PLLSTAT, PLLC_PLLSTAT_GOSTAT)) 
		{
            /* Poll for divide-ratio change and clock alignment to complete */
        }
    
        CSL_FINS (hPllc->regs->PLLCTL, PLLC_PLLCTL_PLLRST,
					CSL_PLLC_PLLCTL_PLLRST_NO);
        
		/* Wait for 4 cycles of the slowest of the  CLKIN/OSCIN
		 * Introducing some arbitrary delay.
         */
        
		loopCount = 65000;
        while (loopCount--)
			asm("   NOP");
            
        /* PLL Control register */
        hPllc->regs->PLLCTL   = config->PLLCTL;

		/* Configure the reset */

		if ((config->RSTCTRL & CSL_PLLC_RSTCTRL_KEY_MASK) == CSL_PLLC_RSTCTRL_VALID_KEY)
		{
			hPllc->regs->RSTCTRL  = config->RSTCTRL;
	        hPllc->regs->RSTCFG   = config->RSTCFG;
		}
		else status = CSL_ESYS_INVPARAMS;
    }
    
    return status;
}

