/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** @file csl_pllcOpen.c
 *
 *  @brief File for functional layer of CSL API @a CSL_pllcOpen()
 *
 *  Path: \(CSLPATH)\src\pllc
 *
 */

/*  ============================================================================
 *  Revision History
 *  ================
 * 20-Mar-2008 Added PLLC for new soc
 * 09-Sept-2008 Updated for Doxygen
 *  ============================================================================
 */

#include <csl_pllc.h>

#pragma CODE_SECTION (CSL_pllcOpen, ".text:csl_section:pllc");
CSL_PllcHandle CSL_pllcOpen (
    CSL_PllcObj               *pPllcObj,
    CSL_InstNum                pllcNum,
    CSL_PllcParam             *pPllcParam,
    CSL_Status                *pStatus
)
{
    CSL_Status                status;
    CSL_PllcHandle            hPllc = NULL;
    CSL_PllcBaseAddress       baseAddress;

    if (pPllcObj == NULL)
        *pStatus = CSL_ESYS_INVPARAMS;
    else 
	{
        status = CSL_pllcGetBaseAddress (pllcNum, pPllcParam, &baseAddress);
    
        if (status == CSL_SOK) 
		{
            pPllcObj->regs     = baseAddress.regs;
            pPllcObj->pllcNum  = (CSL_InstNum) pllcNum;
            hPllc              = (CSL_PllcHandle) pPllcObj;
        }
        else 
		{
            pPllcObj->regs     = (CSL_PllcRegsOvly)NULL;
            pPllcObj->pllcNum  = (CSL_InstNum)-1;
        }
    
        *pStatus = status;
    }

    return hPllc;
}

