/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2008
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * ============================================================================
 */

/** ===========================================================================
 * @file csl_pscGetHwStatus.c
 *
 * @brief File for functional layer of CSL API CSL_pscGetHwStatus()
 *
 * @path $(CSLPATH)\src\psc
 *
 * @desc The CSL_pscGetHwStatus() function definition & it's associated
 *       functions
 * ============================================================================
 */

/* ============================================================================
 * Revision History
 * ===============
 * 29-Jun-2006 TRR File Created.
 * 27-Oct-2008 Ported from old soc to new soc
 * ============================================================================
 */

#include <csl_psc.h>
#include <csl_pscAux.h>

#pragma CODE_SECTION (CSL_pscGetHwStatus, ".text:csl_section:psc");
CSL_Status CSL_pscGetHwStatus (
    CSL_PscHandle        hPsc,
    CSL_PscHwStatusQuery query,
    void                 *response
)
{
    CSL_Status status = CSL_SOK;

    if (hPsc == NULL){
        return CSL_ESYS_BADHANDLE;
    }

    if (response == NULL){
        return CSL_ESYS_INVPARAMS;
    }
    
    switch (query) {
        case CSL_PSC_QUERY_MODULE_STAT:
            CSL_pscGetModuleStat(hPsc, (CSL_PscmoduleState *)response);
            break;

        case CSL_PSC_QUERY_PWRDMN_STAT:
            CSL_pscGetPwrDomainStat(hPsc, (CSL_PscPwrdmnState *)response);
            break;

        case CSL_PSC_QUERY_PWRDMN_TRANS_STAT:
            CSL_pscGetPwrDmnTransStat(hPsc, (CSL_PscPwrDmnTransState *)response);
            break;

        default:
            status = CSL_ESYS_INVQUERY;
		    break;
    }

    return status;
}

