/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2008
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * =============================================================================
 */

/** ===========================================================================
 * @file csl_pscHwControl.c
 *
 * @brief File for functional layer of CSL API CSL_pscHwControl()
 *
 * @path $(CSLPATH)\src\psc
 *
 * @desc The CSL_pscHwControl() function definition & it's associated
 *       functions
 *
 */

/* ============================================================================
 * Revision History
 * ===============
 * 29-Jun-2006 TRR File Created.
 * 27-Oct-2008 Ported from old soc to new soc
 * ============================================================================
 */

#include <csl_psc.h>
#include <csl_pscAux.h>

#pragma CODE_SECTION (CSL_pscHwControl, ".text:csl_section:psc");
CSL_Status  CSL_pscHwControl (
    CSL_PscHandle       hPsc,
    CSL_PscHwControlCmd cmd,
    void                *arg
)
{
    CSL_Status status = CSL_SOK ;

    if (hPsc == NULL) {
        return CSL_ESYS_BADHANDLE;
    }

	if (arg == NULL) {
        return CSL_ESYS_INVPARAMS;
    }

    switch (cmd) {
        /* Enable clock */
        case CSL_PSC_CMD_ENABLE_MODULE:
            status = CSL_PscEnableClock(hPsc, (CSL_PscPeripherals *)arg);
            break;

        /* Enable power domain tansition */
        case CSL_PSC_CMD_PWRDMN_TRNS:
            CSL_PscPwrDomainTrans(hPsc, (CSL_PscPowerDomain *)arg);
            break;

        /* Enable Power domain */
        case CSL_PSC_CMD_ENABLE_PWRDMN:
            status = CSL_PscEnablePwrdmn(hPsc, (CSL_PscPowerDomain *)arg);
            break;

        default:
            status = CSL_ESYS_INVCMD;
	        break;
    }

    return status;
}

