/* =============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2008
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/* ============================================================================
 * @file csl_pscOpen.c
 *
 * @brief File for functional layer of CSL API CSL_pscOpen()
 *
 * @Path $(CSLPATH)\src\psc
 *
 * @desc The CSL_pscOpen() function definition & it's associated
 *       functions
 * ============================================================================
 */

/* ============================================================================
 * Revision History
 * ===============
 * 29-Jun-2006 TRR File Created.
 * 27-Oct-2008 Ported from old soc to new soc
 * ============================================================================
 */

#include <csl_psc.h>

#pragma CODE_SECTION(CSL_pscOpen, ".text:csl_section:psc");
CSL_PscHandle CSL_pscOpen (
    CSL_PscObj   *pPscObj,
    CSL_InstNum  pscNum,
    CSL_PscParam *pPscParam,
    CSL_Status   *pStatus
)
{
    CSL_Status st;
    CSL_PscHandle hPsc;
    CSL_PscBaseAddress baseAddress;

	if (pStatus == NULL) {
        hPsc = (CSL_PscHandle)NULL;
        return hPsc;
    }

    if (pPscObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
        hPsc    = (CSL_PscHandle)NULL;
        return hPsc;
    }

    st = CSL_pscGetBaseAddress(pscNum, pPscParam, &baseAddress);

    if (st == CSL_SOK) {
        pPscObj->regs = baseAddress.regs;
        pPscObj->perNum = (CSL_InstNum)pscNum;
        hPsc = (CSL_PscHandle)pPscObj;
    }
    else {
        pPscObj->regs = (CSL_PscRegsOvly)NULL;
        pPscObj->perNum = (CSL_InstNum)-1;
        hPsc = (CSL_PscHandle)NULL;
    }

    if (pStatus != NULL) {
        *pStatus = st;
    }

    return hPsc;
}

