/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * ============================================================================
 */

/** ============================================================================
 *   @file  csl_pwrdwnGetHwStatus.c
 *
 *   @path  $(CSLPATH)\src\pwrdwn
 *
 *   @desc  File for functional layer of CSL API CSL_pwrdwnGetHwStatus ()
 *
 */
 
/* =============================================================================
 * Revision History
 * ================
 * 16-Jul-2004  Ruchika Kharwar File Created
 * 23-Apr-2008 Removed L2 PWRDWN and added query for PDCCMD MEGPD.
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
 
#include <csl_pwrdwn.h>
#include <csl_pwrdwnAux.h>


#pragma CODE_SECTION (CSL_pwrdwnGetHwStatus, ".text:csl_section:pwrdwn");
CSL_Status CSL_pwrdwnGetHwStatus (
    CSL_PwrdwnHandle        hPwrdwn,
    CSL_PwrdwnHwStatusQuery query,
    void                    *response
)
{

    CSL_Status status = CSL_SOK;
    
    if (hPwrdwn == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }

    else {
        switch (query) {
#if 0 /* PowerDown is not supported for L2 */
            case CSL_PWRDWN_QUERY_PAGE0_STATUS:
                CSL_pwrdwnGetPage0SleepStatus(hPwrdwn, \
                                              (CSL_PwrdwnPortData *)response);
                break;

            case CSL_PWRDWN_QUERY_PAGE1_STATUS:
                CSL_pwrdwnGetPage1SleepStatus(hPwrdwn, \
                                              (CSL_PwrdwnPortData *)response);
                break;
#endif
			case CSL_PWRDWN_QUERY_MEGPD_STATUS:
                *(Uint8*)response = CSL_pwrdwnGetMegpdStatus(hPwrdwn);
                break;

            default:
                status = CSL_ESYS_INVQUERY ;
                break;
        }
    }
    return status;
}
