/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2008
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * ============================================================================
 */

/** ============================================================================
 *   @file  csl_pwrdwnHwControl.c
 *
 *   @path  $(CSLPATH)\src\pwrdwn
 *
 *   @desc  File for functional layer of CSL API CSL_pwrdwnHwControl ()
 *
 */
 
/* =============================================================================
 * Revision History
 * ================
 * 16-Jul-2004  Ruchika Kharwar File Created
 * 23-Apr-2008 Removed L2 PWRDWN and added configure for PDCCMD MEGPD.
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
 
#include <csl_pwrdwn.h>
#include <csl_pwrdwnAux.h>

#pragma CODE_SECTION (CSL_pwrdwnHwControl, ".text:csl_section:pwrdwn");

CSL_Status CSL_pwrdwnHwControl (
    CSL_PwrdwnHandle        hPwrdwn,
    CSL_PwrdwnHwControlCmd  cmd,
    void                    *arg
)
{
    CSL_Status status = CSL_SOK;
    
    if (hPwrdwn == NULL) {
        return CSL_ESYS_BADHANDLE;
    }
    
    else if ((arg == NULL)  && ((cmd >= 0) && \
                    (cmd <= CSL_PWRDWN_CMD_PAGE1_WAKE))) {
        return CSL_ESYS_INVPARAMS;
    } 

    else {
        switch (cmd) {
#if 0 /* PowerDown is not supported for L2 */
            case CSL_PWRDWN_CMD_PAGE0_SLEEP:
                status = CSL_pwrdwnPage0Sleep(hPwrdwn, (CSL_PwrdwnPortData *)arg);
                break;

            case CSL_PWRDWN_CMD_PAGE1_SLEEP:
                status = CSL_pwrdwnPage1Sleep(hPwrdwn, (CSL_PwrdwnPortData *)arg);
                break;

            case CSL_PWRDWN_CMD_PAGE0_WAKE:
                status = CSL_pwrdwnPage0Wake(hPwrdwn, (CSL_PwrdwnPortData *)arg);
                break;

            case CSL_PWRDWN_CMD_PAGE1_WAKE:
                status = CSL_pwrdwnPage1Wake(hPwrdwn, (CSL_PwrdwnPortData *)arg);
                break;
#endif
			case CSL_PWRDWN_CMD_PDCCMD_MEGPD_NORMAL:
                status = CSL_pwrdwnMegpd(hPwrdwn, 0);
                break;
			case CSL_PWRDWN_CMD_PDCCMD_MEGPD_SLEEP:
                status = CSL_pwrdwnMegpd(hPwrdwn, 1);
                break;
            default:
                status = CSL_ESYS_INVCMD ;
                break;
        }
    }
    return status;
}
