/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * ============================================================================
 */

/** ============================================================================
 *   @file  csl_pwrdwnOpen.c
 *
 *   @path  $(CSLPATH)\src\pwrdwn
 *
 *   @desc  File for functional layer of CSL API CSL_pwrdwnOpen ()
 *
 */
 
/* =============================================================================
 * Revision History
 * ===============
 *  16-Jul-2004  Ruchika Kharwar File Created
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */

#include <csl_pwrdwn.h>

#pragma CODE_SECTION (CSL_pwrdwnOpen, ".text:csl_section:pwrdwn");
CSL_PwrdwnHandle CSL_pwrdwnOpen (
    CSL_PwrdwnObj       *pPwrdwnObj,   
    CSL_InstNum         pwrdwnNum,     
    CSL_PwrdwnParam     *pPwrdwnParam, 
    CSL_Status          *pStatus
)
{
    CSL_PwrdwnBaseAddress baseAddress;
    CSL_PwrdwnHandle hPwrdwn = (CSL_PwrdwnHandle)NULL;

    
    if (pStatus == NULL) {
        /* do nothing : already the module is initialized to NULL */
    }
    
    else if (pPwrdwnObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }

    else {
        *pStatus = CSL_pwrdwnGetBaseAddress(pwrdwnNum, pPwrdwnParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pPwrdwnObj->pdcRegs = baseAddress.regs;
            pPwrdwnObj->l2pwrdwnRegs = baseAddress.l2pwrdwnRegs;
            pPwrdwnObj->instNum = (CSL_InstNum)pwrdwnNum;
            hPwrdwn = (CSL_PwrdwnHandle)pPwrdwnObj;
        }
        else {
            pPwrdwnObj->pdcRegs = (CSL_PdcRegsOvly)NULL;
            pPwrdwnObj->l2pwrdwnRegs = NULL;
            pPwrdwnObj->instNum = (CSL_InstNum)-1;
        }      
    }
    return (hPwrdwn);
}

