/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 *  ===========================================================================
 */
/** ============================================================================
 * @file csl_srioOpen.c
 *
 * @brief File for functional layer of CSL API CSL_srioOpen()
 *
 * @Path $(CSLPATH)\srio\src
 *
 * @desc The CSL_srioOpen() function definition and it's associated functions.
 * ============================================================================
 */
/* ============================================================================
 * Revision History
 * ===============
 * 29-Aug-2005 PSK File Created.
 * ============================================================================
 */
#include <csl_srio.h>


#pragma CODE_SECTION (CSL_srioOpen, ".text:csl_section:srio");
CSL_SrioHandle CSL_srioOpen (
    CSL_SrioObj      *pSrioObj,
    CSL_InstNum      srioNum,
    CSL_SrioParam    *pSrioParam,
    CSL_Status       *pStatus
)
{
    CSL_SrioHandle         hSrio = (CSL_SrioHandle)NULL;
    CSL_SrioBaseAddress    baseAddress;

    if (pStatus == NULL) {
        /* do nothing : module handle is already initialized to NULL */
    }
    else if (pSrioObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else {
        *pStatus = CSL_srioGetBaseAddress(srioNum, pSrioParam, &baseAddress);

        if (*pStatus == CSL_SOK) {
            pSrioObj->regs = baseAddress.regs;
            pSrioObj->perNum = (CSL_InstNum)srioNum;
            hSrio = (CSL_SrioHandle)pSrioObj;
        }
        else {
            pSrioObj->regs = (CSL_SrioRegsOvly)NULL;
            pSrioObj->perNum = (CSL_InstNum)-1;
        }
    }
    return (hSrio);
}

