/* =============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 * =============================================================================
 */ 
/** ============================================================================
 *   @file  csl_tetbGetHwStatus.c
 *
 *   @path  $(CSLPATH)\tetb\src
 *
 *   @desc  
 *
 */
/* =============================================================================
 * Revision History
 * ================
 * 24-Apr-2008 File created
 *
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <csl_tetb.h>
#include <csl_tetbAux.h>


#pragma CODE_SECTION (CSL_tetbGetHwStatus, ".text:csl_section:tetb");

CSL_Status  CSL_tetbGetHwStatus (
    CSL_TetbHandle           hTetb,
    CSL_TetbHwStatusQuery    query,
    void                    *response
)
{
    CSL_Status status = CSL_SOK;

    if (hTetb == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }

    else {
        switch (query) {
            case CSL_TETB_QUERY_RAM_FULL:
                /* RAM Full (RAM write pointer has wrapped around) */
                CSL_tetbGetRam(hTetb, response);
                break;

            case CSL_TETB_QUERY_TRIG_STAUS:
                /* Trigger bit set when a trigger has been observed */
                CSL_tetbGetTrigSts(hTetb, response);
                break;

            case CSL_TETB_QUERY_ACQUISITION_COMPLETE:
                /* Acquisition complete */
                CSL_tetbGetAcq(hTetb, response);
                break;

            case CSL_TETB_QUERY_DEVICE_ID:
                /* DID - Device ID */
                *(Uint32 *)response = hTetb->regs->DID;
                break;

            case CSL_TETB_QUERY_DEVICE_TYPE:
                /* Device Type Identification Register */
                CSL_tetbGetDevType(hTetb, response);
                break;

            case CSL_TETB_QUERY_RAM_DEPTH:
                /* Read the RAM size */
                CSL_tetbGetRamDepth(hTetb, response);
                break;       

            case CSL_TETB_QUERY_READ_POINTER:
                /* Read RAM read pointer value */
                CSL_tetbGetReadPointer(hTetb, response);
                break;       

            case CSL_TETB_QUERY_WRITE_POINTER:
                /* Read RAM write pointer value */
                CSL_tetbGetWritePointer(hTetb, response);
                break;       

            case CSL_TETB_QUERY_TRACECAP_STATUS:
                /* Read the trace capture value */
                CSL_tetbGetTraceCapture(hTetb, response);
                break;       

            case CSL_TETB_QUERY_TRIGGERCOUNT:
                /* Read the value of Trigger Counter  */
                CSL_tetbGetTriggerCounter(hTetb, response);
                break;       

            case CSL_TETB_QUERY_HALF_FULL_ENABLE:
                /* Read the value HalfFull interrupt bit */
                CSL_tetbGetHalffull_Enable(hTetb, response);
                break;

            case CSL_TETB_QUERY_FULL_ENABLE:
                /* Read the value Full interrupt bit */
                CSL_tetbGetFull_Enable(hTetb, response);
                break;

            case CSL_TETB_QUERY_OVERFLOW_ENABLE:
                /* Read the value Overflow interrupt bit */
                CSL_tetbGetOverflow_Enable(hTetb, response);
                break;

			case CSL_TETB_QUERY_UNDERFLOW_ENABLE:
                /* Read the value Underflow interrupt bit */
                CSL_tetbGetUnderflow_Enable(hTetb, response);
                break;			

            case CSL_TETB_QUERY_ACQ_COMP_ENABLE:
                /* Read the value Acquisition Complete interrupt bit */
                CSL_tetbGetAcqComp_Enable(hTetb, response);
                break;

            default:
                status = CSL_ESYS_INVQUERY;
                break;
        }
    }    
    return(status);
}

