/* =============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 * =============================================================================
 */ 
/** ============================================================================
 *   @file  csl_tetbHwControl.c
 *
 *   @path  $(CSLPATH)\tetb\src
 *
 *   @desc  
 *    - The CSL_tetbHwControl() function definition & it's associated functions
 *
 */
/* =============================================================================
 * Revision History
 * ================
 * 24-Apr-2008 File created
 *
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <csl_tetb.h>


#pragma CODE_SECTION (CSL_tetbHwControl, ".text:csl_section:tetb");

CSL_Status  CSL_tetbHwControl (
    CSL_TetbHandle        hTetb,
    CSL_TetbControlCmd    cmd,
    void*                arg
)
{
    CSL_Status          status  = CSL_SOK;
    Uint32              argv = *(Uint32*)arg;
    
    if (hTetb == NULL) 
        status = CSL_ESYS_BADHANDLE;
    else 
	{
        switch (cmd) 
		{

            case CSL_TETB_CMD_SET_RAM_RD_POINTER:
                /* RAM read pointer register */
                CSL_FINS(hTetb->regs->RRP, TETB_RRP_RRP, argv);
                break;

            case CSL_TETB_CMD_SET_RAM_WR_POINTER:
                /* RAM write pointer register */
                CSL_FINS(hTetb->regs->RWP, TETB_RWP_RWP, argv);
                break;

            case CSL_TETB_CMD_SET_TRIGG_COUNT:
                /* Trigger Counter Register */
                CSL_FINS(hTetb->regs->TRG, TETB_TRG_TRG, argv);
                break;

            case CSL_TETB_CMD_ENA_TRACE_CAPTURE:
                /* Trace Capture Enable */
                CSL_FINST(hTetb->regs->CTL, TETB_CTL_TRACECAPTEN, ENABLE);
                break;

            case CSL_TETB_CMD_DIS_TRACE_CAPTURE:
                /* Trace Capture Disable */
                CSL_FINST(hTetb->regs->CTL, TETB_CTL_TRACECAPTEN, DISABLE);
                break;

			case CSL_TETB_CMD_SET_TI_MODE:
                /* Set TI Mode in TCTL Register */
                CSL_FINS(hTetb->regs->TCTL, TETB_TCTL_TI_MODE, argv);
                break;

            case CSL_TETB_CMD_SET_BUFF_MODE:
                /* Set Stop Buffer Mode */
                CSL_FINS(hTetb->regs->TCTL, TETB_TCTL_STOP_BUF, argv);
                break;

			case CSL_TETB_CMD_RESET:
                /* Set Stop Buffer Mode */
                CSL_FINST(hTetb->regs->TCTL, TETB_TCTL_RST, RESET_YES);
                break;

			case CSL_TETB_CMD_ENABLE_HALF_FULL:
                /* Enable Half Full Interrupt */
                CSL_FINST(hTetb->regs->IESST, TETB_IESST_HALFFULL_EN_SET, SET);
                break;

			case CSL_TETB_CMD_ENABLE_FULL:
                /* Enable Full Interrupt */
                CSL_FINST(hTetb->regs->IESST, TETB_IESST_FULL_EN_SET, SET);
                break;

			case CSL_TETB_CMD_ENABLE_OVERFLOW:
                /* Enable Overflow Interrupt */
                CSL_FINST(hTetb->regs->IESST, TETB_IESST_OVERFLOW_EN_SET, SET);
                break;

			case CSL_TETB_CMD_ENABLE_UNDERFLOW:
                /* Enable Underflow Interrupt */
                CSL_FINST(hTetb->regs->IESST, TETB_IESST_UNDERFLOW_EN_SET, SET);
                break;

			case CSL_TETB_CMD_ENABLE_ACQ_COMP:
                /* Enable Acquisition Complete Interrupt */
                CSL_FINST(hTetb->regs->IESST, TETB_IESST_ACQ_COMP_EN_SET, SET);
                break;
				
			case CSL_TETB_CMD_DISABLE_HALF_FULL:
                /* Disable Half Full Interrupt */
                CSL_FINST(hTetb->regs->IECST, TETB_IECST_HALFFULL_EN_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_DISABLE_FULL:
                /* Disable Full Interrupt */
                CSL_FINST(hTetb->regs->IECST, TETB_IECST_FULL_EN_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_DISABLE_OVERFLOW:
                /* Disable Overflow Interrupt */
                CSL_FINST(hTetb->regs->IECST, TETB_IECST_OVERFLOW_EN_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_DISABLE_UNDERFLOW:
                /* Disable Underflow Interrupt */
                CSL_FINST(hTetb->regs->IECST, TETB_IECST_UNDERFLOW_EN_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_DISABLE_ACQ_COMP:
                /* Disable Acquisition Complete Interrupt */
                CSL_FINST(hTetb->regs->IECST, TETB_IECST_ACQ_COMP_EN_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_SET_HALF_FULL:
                /* Set Half Full Interrupt */
                CSL_FINST(hTetb->regs->ISST, TETB_ISST_HALFFULL_SET, SET);
                break;

			case CSL_TETB_CMD_SET_FULL:
                /* Set Full Interrupt */
                CSL_FINST(hTetb->regs->ISST, TETB_ISST_FULL_SET, SET);
                break;

			case CSL_TETB_CMD_SET_OVERFLOW:
                /* Set Overflow Interrupt */
                CSL_FINST(hTetb->regs->ISST, TETB_ISST_OVERFLOW_SET, SET);
                break;

			case CSL_TETB_CMD_SET_UNDERFLOW:
                /* Set Underflow Interrupt */
                CSL_FINST(hTetb->regs->ISST, TETB_ISST_UNDERFLOW_SET, SET);
                break;

			case CSL_TETB_CMD_SET_ACQ_COMP:
                /* Set Acquisition Complete Interrupt */
                CSL_FINST(hTetb->regs->ISST, TETB_ISST_ACQ_COMP_SET, SET);
                break;
				
			case CSL_TETB_CMD_CLEAR_HALF_FULL:
                /* Clear Half Full Interrupt */
                CSL_FINST(hTetb->regs->ICST, TETB_ICST_HALFFULL_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_CLEAR_FULL:
                /* Clear Full Interrupt */
                CSL_FINST(hTetb->regs->ICST, TETB_ICST_FULL_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_CLEAR_OVERFLOW:
                /* Clear Overflow Interrupt */
                CSL_FINST(hTetb->regs->ICST, TETB_ICST_OVERFLOW_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_CLEAR_UNDERFLOW:
                /* Clear Underflow Interrupt */
                CSL_FINST(hTetb->regs->ICST, TETB_ICST_UNDERFLOW_CLEAR, CLEAR);
                break;

			case CSL_TETB_CMD_CLEAR_ACQ_COMP:
                /* Clear Acquisition Complete Interrupt */
                CSL_FINST(hTetb->regs->ICST, TETB_ICST_ACQ_COMP_CLEAR, CLEAR);
                break;

            default:
                status = CSL_ESYS_INVCMD;
                break;
        }
    }    
    return (status);
}
