/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2008
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** @file  csl_tetbOpen.c
 *
 *  @path $(CSLPATH)\tetb\src
 *
 *  @brief File for functional layer of CSL API @a CSL_tetbOpen()
 *
 */
/* =============================================================================
 * Revision History
 * ================
 * 24-Apr-2008 File created.
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */
#include <csl_tetb.h>


#pragma CODE_SECTION (CSL_tetbOpen, ".text:csl_section:tetb");

CSL_TetbHandle CSL_tetbOpen (
    CSL_TetbObj		*pTetbObj,
    CSL_InstNum 	tetbNum,
    CSL_TetbParam 	*pTetbParam,
    CSL_Status 		*pStatus
)
{
    CSL_TetbHandle           hTetb = (CSL_TetbHandle) NULL;
    CSL_TetbBaseAddress      baseAddress;

    if (pStatus == NULL) 
	{
        /* do nothing : already the module is initialized to NULL */ 
    }

    else if (pTetbObj == NULL) 
        *pStatus = CSL_ESYS_INVPARAMS;        
    else 
	{
        *pStatus = CSL_tetbGetBaseAddress(tetbNum, pTetbParam, &baseAddress);

        if (*pStatus == CSL_SOK) 
		{
            pTetbObj->regs = baseAddress.regs;
            pTetbObj->tetbNum = (CSL_InstNum)tetbNum;
            hTetb = (CSL_TetbHandle)pTetbObj;
            
        }
        else 
		{
            pTetbObj->regs = (CSL_TetbRegsOvly) NULL;
            pTetbObj->tetbNum = (CSL_InstNum) -1;
        }                                      
    }
    return (hTetb);
}

