/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * ============================================================================
 */

/** ===========================================================================
 * @file csl_tmrGetHwStatus.c
 *
 * @brief File for functional layer of CSL API CSL_tmrGetHwStatus() 
 * 
 * @path $(CSLPATH)\src\timer
 *
 * @desc The CSL_tmrGetHwStatus() function definition & it's associated
 *       functions 
 * ============================================================================
 */

/* ============================================================================
 * Revision History
 * ===============
 * 1-Sept-2004 HMM File Created.
 * 29-Jul-2005 PSK updted changes acooriding to revised timer spec. the number
 *                 convention TIM12, TIM34 are changed to TIMLO and TIMHI.  
 * 09-Sept-2008 Updated for Doxygen
 * ============================================================================
 */

#include <csl_tmr.h>
#include <csl_tmrAux.h>

#pragma CODE_SECTION (CSL_tmrGetHwStatus, ".text:csl_section:tmr");
CSL_Status CSL_tmrGetHwStatus (
    CSL_TmrHandle        hTmr,
    CSL_TmrHwStatusQuery query,
    void                 *response
)
{
    CSL_Status status = CSL_SOK;

    if (hTmr == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (response == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        switch (query) {
            case CSL_TMR_QUERY_COUNT_LO:
                CSL_tmrGetTimLoCount(hTmr, (Uint32 *)response);
                break;
    
            case CSL_TMR_QUERY_COUNT_HI:
                CSL_tmrGetTimHiCount(hTmr, (Uint32 *)response);
                break;
    
            case CSL_TMR_QUERY_TSTAT_LO:
                *((CSL_TmrTstat *)response) = CSL_tmrGetTstatLoStatus(hTmr);
                break;
    
            case CSL_TMR_QUERY_TSTAT_HI:
                *((CSL_TmrTstat *)response) = CSL_tmrGetTstatHiStatus(hTmr);
                break;
     
            case CSL_TMR_QUERY_WDFLAG_STATUS:
    		    *((CSL_TmrWdflagBitStatus*)response) = 
                                               CSL_tmrGetWdflagStatus(hTmr); 
    		    break;
    
            default:
                status = CSL_ESYS_INVQUERY;
    		    break;
        }
    }

    return status;
}

