/* ============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 * ============================================================================
 */

/** ===========================================================================
 * @file csl_tmrHwSetupRaw.c
 *
 * @brief File for functional layer of CSL API CSL_tmrHwSetupRaw() 
 * 
 * @path $(CSLPATH)\src\timer
 *
 * @desc The CSL_tmrHwSetupRaw() function definition & it's associated
 *       functions 
 * ============================================================================
 */

/* ============================================================================
 * Revision History
 * ===============
 *  1-Sept-2004 HMM File Created.
 *  29-Jul-2005 PSK Updated changes according to revised timer spec. The number
 *                  convention TIM12, TIM34 are changed to TIMLO and TIMHI.   
 *  03-Apr-2006 ds  Removed "EMUMGT_CLKSPD" configuration
 * 09-Sept-2008 Updated for Doxygen
 * ============================================================================
 */

#include <csl_tmr.h>
#include <csl_tmrAux.h>

#pragma CODE_SECTION(CSL_tmrHwSetupRaw, ".text:csl_section:tmr");
CSL_Status  CSL_tmrHwSetupRaw (
    CSL_TmrHandle hTmr,
    CSL_TmrConfig *config
)
{
    CSL_Status status = CSL_SOK ;

    if (hTmr == NULL) {
        status = CSL_ESYS_BADHANDLE;
    }
    else if (config == NULL) {
        status = CSL_ESYS_INVPARAMS;
    }
    else {
        /* General purpose timer Timer Counter Register Low */
        hTmr->regs->CNTLO = config->CNTLO;
    
        /* General purpose timer Timer Counter Register High */
        hTmr->regs->CNTHI = config->CNTHI;
    
        /* General purpose timer Timer Period Register Low */
        hTmr->regs->PRDLO = config->PRDLO;
    
        /* General purpose timer Timer Period Register High */
        hTmr->regs->PRDHI = config->PRDHI;
    
        /* General purpose timer Timer Control Register */
        hTmr->regs->TCR = config->TCR;
    
        /* General purpose timer Timer Global Control Register */
        hTmr->regs->TGCR = config->TGCR;
    
        /* General purpose timer General purpose Timer Control Register */
        hTmr->regs->WDTCR = config->WDTCR;
    }

    return status;
}

