/* =============================================================================
 * Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 * Use of this software is controlled by the terms and conditions found in the
 * license agreement under which this software has been supplied.
 *  ===========================================================================
 */

/* ============================================================================
 * @file csl_tmrOpen.c
 *
 * @brief File for functional layer of CSL API CSL_tmrOpen() 
 * 
 * @Path $(CSLPATH)\src\timer
 *
 * @desc The CSL_tmrOpen() function definition & it's associated
 *       functions 
 * ============================================================================
 */

/* ============================================================================
 * Revision History
 * ===============
 * 1-Sept-2004 HMM File Created.
 * 29-Jul-2005 PSK Updted changes acooriding to revised timer spec. the number
 *                 convention TIM12, TIM34 are changed to TIMLO and TIMHI. 
 *
 * 09-Sept-2008 Updated for Doxygen
 * ============================================================================
 */

#include <csl_tmr.h>


#pragma CODE_SECTION(CSL_tmrOpen, ".text:csl_section:tmr");
CSL_TmrHandle CSL_tmrOpen (
    CSL_TmrObj   *pTmrObj, 
    CSL_InstNum  tmrNum, 
    CSL_TmrParam *pTmrParam, 
    CSL_Status   *pStatus
)
{
    CSL_Status st;
    CSL_TmrHandle hTmr = NULL;
    CSL_TmrBaseAddress baseAddress;

    if (pStatus == NULL) {
        /* do nothing */
    }
    else if (pTmrObj == NULL) {
        *pStatus = CSL_ESYS_INVPARAMS;
    }
    else {
        st = CSL_tmrGetBaseAddress(tmrNum, pTmrParam, &baseAddress);
    
        if (st == CSL_SOK) {
            pTmrObj->regs = baseAddress.regs;
            pTmrObj->tmrNum = (CSL_InstNum)tmrNum;
            hTmr = (CSL_TmrHandle)pTmrObj;
        }
        else {
            pTmrObj->regs = (CSL_TmrRegsOvly)NULL;
            pTmrObj->tmrNum = (CSL_InstNum)-1;
            hTmr = (CSL_TmrHandle)NULL;
        }
    
        *pStatus = st;
    }

    return hTmr;
}

