/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005                 
 *                                                                              
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.             
 *   ===========================================================================
 */

/**
 *  @file  csl_intcExcep.c
 *
 *  @brief File for functional layer of CSL Exceptions APIs
 *
 *  PATH  $(CSLPATH)\src\intc
 */
 
/* =============================================================================
 *  Revision History
 *  ===============
 * 12-Jun-2004 Ruchika Kharwar File Created
 * 16-Mar-2005 brn modified for doxygen documentation
 * 09-Sept-2008 Updated for Doxygen
 * =============================================================================
 */

#include <csl_intc.h>


#pragma CODE_SECTION (CSL_intcExcepAllEnable, ".text:csl_section:intc");
CSL_Status CSL_intcExcepAllEnable (
        CSL_IntcExcepEn     excepMask,
        CSL_BitMask32       excVal,
        CSL_BitMask32       *prevState
        
)
{
    CSL_Status stat = CSL_SOK;

    if ((prevState) && ((excepMask >= 0) && (excepMask <= 3))) { 
        *prevState = ((CSL_IntcRegsOvly)CSL_INTC_0_REGS)->EXPMASK[excepMask];
        ((CSL_IntcRegsOvly)CSL_INTC_0_REGS)->EXPMASK[excepMask] &= ~excVal;
    }
    else {
        stat = CSL_ESYS_INVPARAMS;
    }
    
    return (stat);
}

#pragma CODE_SECTION (CSL_intcExcepAllDisable, ".text:csl_section:intc");
CSL_Status CSL_intcExcepAllDisable (
        CSL_IntcExcepEn             excepMask,
        CSL_BitMask32               excVal,
        CSL_BitMask32               *prevState
)
{
    CSL_Status stat = CSL_SOK;
    
    if ((prevState) && ((excepMask >= 0) && (excepMask <= 3))) {
        *prevState = ((CSL_IntcRegsOvly)CSL_INTC_0_REGS)->EXPMASK[excepMask];
        ((CSL_IntcRegsOvly)CSL_INTC_0_REGS)->EXPMASK[excepMask] |= excVal;
    }
    else {
        stat = CSL_ESYS_INVPARAMS;
    }
    
    return (stat);
}

#pragma CODE_SECTION (CSL_intcExcepAllRestore, ".text:csl_section:intc");
CSL_Status CSL_intcExcepAllRestore (
        CSL_IntcExcepEn             excepMask,
        CSL_IntcGlobalEnableState   restoreVal
)
{
    CSL_Status stat = CSL_SOK;

    if ((excepMask >= 0) && (excepMask <= 3)) {
        ((CSL_IntcRegsOvly)CSL_INTC_0_REGS)->EXPMASK[excepMask] = restoreVal;
    }
    else {
        stat = CSL_ESYS_INVPARAMS;
    }

    return (stat);
}


#pragma CODE_SECTION (CSL_intcExcepAllClear, ".text:csl_section:intc");
CSL_Status CSL_intcExcepAllClear (
        CSL_IntcExcepEn  excepMask,
        CSL_BitMask32    excVal
)
{
    CSL_Status stat = CSL_SOK;

    if ((excepMask >= 0) && (excepMask <= 3)) {
        ((CSL_IntcRegsOvly)CSL_INTC_0_REGS)->EVTCLR[excepMask] = excVal;
    }
    else{
        stat = CSL_ESYS_INVPARAMS;
    }

    return (stat);
}


#pragma CODE_SECTION (CSL_intcExcepAllStatus, ".text:csl_section:intc");
CSL_Status CSL_intcExcepAllStatus (
        CSL_IntcExcepEn  excepMask,
        CSL_BitMask32    *status     
)
{
    CSL_Status stat = CSL_SOK;

    if ((status) && ((excepMask >= 0) && (excepMask <= 3))) {
        *status = ((CSL_IntcRegsOvly)CSL_INTC_0_REGS)->MEXPFLAG[excepMask] ;
    }
    else {
        stat = CSL_ESYS_INVPARAMS;
    }
    
    return (stat); 
}

